@@ -20,18 +20,18 @@
 #ifndef CCANVAS_H
 #define CCANVAS_H
 
-#include <proj_api.h>
+#include "gis/IGisItem.h"
+
 #include <QMap>
 #include <QPainter>
 #include <QPointer>
 #include <QWidget>
 
-#include "gis/IGisItem.h"
-
 class IDrawContext;
 class CMapDraw;
 class CGrid;
 class CDemDraw;
+class CPoiDraw;
 class QGestureEvent;
 class CGisDraw;
 class CRtDraw;
@@ -57,12 +57,12 @@ class CCanvas : public QWidget
 {
     Q_OBJECT
 public:
-    CCanvas(QWidget * parent, const QString& name);
+    CCanvas(QWidget* parent, const QString& name);
     virtual ~CCanvas();
 
-    static void setOverrideCursor(const QCursor &cursor, const QString&src);
-    static void restoreOverrideCursor(const QString &src);
-    static void changeOverrideCursor(const QCursor& cursor, const QString &src);
+    static void setOverrideCursor(const QCursor& cursor, const QString& src);
+    static void restoreOverrideCursor(const QString& src);
+    static void changeOverrideCursor(const QCursor& cursor, const QString& src);
 
 
     void saveConfig(QSettings& cfg);
@@ -70,7 +70,7 @@ public:
 
     void setupGrid();
     void convertGridPos2Str(const QPointF& pos, QString& str, bool simple);
-    void convertRad2Px(QPointF &pos) const;
+    void convertRad2Px(QPointF& pos) const;
     void convertPx2Rad(QPointF& pos) const;
 
     void setupBackgroundColor();
@@ -88,17 +88,24 @@ public:
     void  setScales(const scales_type_e type);
     scales_type_e getScalesType();
 
-    qreal getElevationAt(const QPointF &pos) const;
-    void  getElevationAt(const QPolygonF& pos, QPolygonF &ele) const;
-    void  getElevationAt(SGisLine &line) const;
+    qreal getElevationAt(const QPointF& pos) const;
+    void  getElevationAt(const QPolygonF& pos, QPolygonF& ele) const;
+    void  getElevationAt(SGisLine& line) const;
 
-    qreal getSlopeAt(const QPointF &pos) const;
+    qreal getSlopeAt(const QPointF& pos) const;
     void getSlopeAt(const QPolygonF& pos, QPolygonF& slope) const;
 
-    void moveMap(const QPointF &delta);
+    void moveTo(const QPointF& newFocus);
+    void moveMap(const QPointF& delta);
     void zoomTo(const QRectF& rect);
+    void zoom(int index);
     void displayInfo(const QPoint& px);
-    poi_t findPOICloseBy(const QPoint& px) const;
+    ///The POIs can be clustered together, so the icon is not necessarily displayed where the POI is.
+    /// Thus the location where to draw the highlight is separately given
+    void findPoiCloseBy(const QPoint& px, QSet<poi_t>& poiItems, QList<QPointF>& posPoiHighlight) const;
+    ///The POIs can be clustered together, so the icon is not necessarily displayed where the POI is.
+    /// Thus the location where to draw the highlight is separately given
+    void findPoisIn(const QRectF& degRect, QSet<poi_t>& poiItems, QList<QPointF>& posPoiHighlight) const;
 
     enum redraw_e
     {
@@ -108,6 +115,7 @@ public:
         , eRedrawGis = 0x04
         , eRedrawMouse = 0x08
         , eRedrawRt = 0x10
+        , eRedrawPoi = 0x20
         , eRedrawAll = 0xFFFFFFFF
     };
 
@@ -130,7 +138,7 @@ public:
     void setMousePrint();
     void setMouseSelect();
 
-    void showProfileAsWindow(bool yes);
+    void showProfileAsWindow();
     void showProfile(bool yes);
 
     void buildHelpText();
@@ -162,7 +170,7 @@ public:
      */
     bool findPolylineCloseBy(const QPointF& pt1, const QPointF& pt2, qint32 threshold, QPolygonF& polyline);
 
-    void print(QPainter &p, const QRectF& area, const QPointF &focus, bool printScale = true);
+    void print(QPainter& p, const QRectF& area, const QPointF& focus, bool printScale = true);
 
     /**
        @brief Set a single map file to be shown on the canvas
@@ -184,8 +192,11 @@ public:
 
     static qreal gisLayerOpacity;
 
+    void linkMapViewEnabled();
+
 signals:
     void sigMousePosition(const QPointF& pos, qreal ele, qreal slope);
+    void sigMoveAndZoom(int index, const QPointF& focus);
     void sigZoom();
     void sigMove();
     void sigResize(const QSize& size);
@@ -196,18 +207,18 @@ public slots:
     void slotCheckTrackOnFocus();
 
 protected:
-    bool event(QEvent *) override;
-    bool gestureEvent(QGestureEvent *e);
-    void resizeEvent(QResizeEvent *e) override;
-    void paintEvent(QPaintEvent  *e) override;
-    void mousePressEvent(QMouseEvent  *e) override;
-    void mouseMoveEvent(QMouseEvent  *e) override;
-    void mouseReleaseEvent(QMouseEvent  *e) override;
-    void mouseDoubleClickEvent(QMouseEvent  *e) override;
-    void wheelEvent(QWheelEvent  *e) override;
-    void enterEvent(QEvent       *e) override;
-    void leaveEvent(QEvent       *e) override;
-    void keyPressEvent(QKeyEvent    *e) override;
+    bool event(QEvent*) override;
+    bool gestureEvent(QGestureEvent* e);
+    void resizeEvent(QResizeEvent* e) override;
+    void paintEvent(QPaintEvent* e) override;
+    void mousePressEvent(QMouseEvent* e) override;
+    void mouseMoveEvent(QMouseEvent* e) override;
+    void mouseReleaseEvent(QMouseEvent* e) override;
+    void mouseDoubleClickEvent(QMouseEvent* e) override;
+    void wheelEvent(QWheelEvent* e) override;
+    void enterEvent(QEvent* e) override;
+    void leaveEvent(QEvent* e) override;
+    void keyPressEvent(QKeyEvent* e) override;
 
 
 private slots:
@@ -221,7 +232,7 @@ private:
     {
         drawScale(p, rect());
     }
-    void setZoom(bool in, redraw_e & needsRedraw);
+    void setZoom(bool in, redraw_e& needsRedraw);
     void setSizeTrackProfile();
     /**
        @brief Resize all registered drwa context objects
@@ -242,34 +253,39 @@ private:
 
     bool showTrackOverlays = true;
 
-    QColor backColor = "#FFFFBF";       //< the background color used in case of missing map tiles
+    QColor backColor = 0x00FFFFBF;      //< the background color used in case of missing map tiles
     redraw_e needsRedraw = eRedrawAll;  //< set true to initiate a complete redraw of the screen content
-    CMapDraw * map;                     //< the map object attached to this canvas
-    CDemDraw * dem;                     //< the elevation data layer attached to this canvas
-    CGisDraw * gis;                     //< the GIS data layer attached to this canvas
-    CRtDraw * rt;                       //< the real time data layer attached to this canvas
-    CGrid * grid;                       //< the grid attached to this canvas
+    CMapDraw* map;                      //< the map object attached to this canvas
+    CDemDraw* dem;                      //< the elevation data layer attached to this canvas
+    CPoiDraw* poi;                      //< the poi database attached to this canvas
+    CGisDraw* gis;                      //< the GIS data layer attached to this canvas
+    CRtDraw* rt;                        //< the real time data layer attached to this canvas
+    CGrid* grid;                        //< the grid attached to this canvas
 
     QList<IDrawContext*> allDrawContext;
 
     /// the current point of focus (usually the canvas center)
-    QPointF posFocus {12.00 * DEG_TO_RAD, 49.00 * DEG_TO_RAD};
+    QPointF posFocus {0.209439510239, 0.855211333477};
 
     /// the mouse handler
-    CMouseAdapter * mouse;
+    CMouseAdapter* mouse;
 
     /// tool tip timer for vector map tool tips
-    QTimer * timerToolTip;
+    QTimer* timerToolTip;
     /// the position of the tool tip
     QPoint posToolTip;
 
     /// load indicator for maps
-    QMovie * loadIndicator1;
-    QLabel * mapLoadIndicator;
+    QMovie* loadIndicator1;
+    QLabel* mapLoadIndicator;
 
     /// load indicator for DEM
-    QMovie * loadIndicator2;
-    QLabel * demLoadIndicator;
+    QMovie* loadIndicator2;
+    QLabel* demLoadIndicator;
+
+    /// load indicator for POI
+    QMovie* loadIndicator3;
+    QLabel* poiLoadIndicator;
 
     QPointer<CColorLegend> colorLegend;
 
@@ -277,29 +293,29 @@ private:
     int zoomAngleDelta = 0;
 
     /// timer to poll for track gaining/loosing focus
-    QTimer * timerTrackOnFocus;
+    QTimer* timerTrackOnFocus;
     /// the key of the currently focused track
     IGisItem::key_t keyTrackOnFocus;
     /// the track profile plot
     QPointer<IPlot>  plotTrackProfile;
     /// a label with a track
-    QLabel * labelTrackStatistic;
+    QLabel* labelTrackStatistic;
 
-    QLabel * labelTrackInfo;
+    QLabel* labelTrackInfo;
 
-    QTextBrowser * textStatusMessages;
+    QTextBrowser* textStatusMessages;
     QMap<QString, QString> statusMessages;
 
     QMutex mousePressMutex;
     bool mouseLost = false;
 
-    QTextBrowser * labelHelp = nullptr;
+    QTextBrowser* labelHelp = nullptr;
 };
 
 class CCanvasCursorLock
 {
 public:
-    CCanvasCursorLock(const QCursor &cursor, const QString& src)
+    CCanvasCursorLock(const QCursor& cursor, const QString& src)
         : src(src)
     {
         CCanvas::setOverrideCursor(cursor, src);
