@@ -27,8 +27,8 @@
 #define N_DEFAULT_ZOOM_LEVELS 31
 const qreal IDrawContext::scalesDefault[N_DEFAULT_ZOOM_LEVELS] =
 {
-    0.10,  0.15,  0.20,  0.30,   0.50,   0.70,   1.0,    1.5,    2.0,    3.0,
-    5.0,   7.0,  10.0,  15.0,   20.0,   30.0,   50.0,   70.0,  100.0,  150.0,
+    0.10, 0.15, 0.20, 0.30, 0.50, 0.70, 1.0, 1.5, 2.0, 3.0,
+    5.0, 7.0, 10.0, 15.0, 20.0, 30.0, 50.0, 70.0, 100.0, 150.0,
     200.0, 300.0, 500.0, 700.0, 1000.0, 1500.0, 2000.0, 3000.0, 5000.0, 7000.0,
     10000.0
     //, 15000.0, 20000.0, 30000.0, 50000.0, 70000.0
@@ -37,9 +37,9 @@ const qreal IDrawContext::scalesDefault[N_DEFAULT_ZOOM_LEVELS] =
 #define N_SQUARE_ZOOM_LEVELS 17
 const qreal IDrawContext::scalesSquare[N_SQUARE_ZOOM_LEVELS] =
 {
-    0.1492910709,    0.2985821417,    0.5971642834,    1.1943285668,
-    2.3886571336,    4.7773142672,    9.5546285344,   19.1092570688,
-    38.2185141376,   76.4370282752,  152.8740565504,  305.7481131008,
+    0.1492910709, 0.2985821417, 0.5971642834, 1.1943285668,
+    2.3886571336, 4.7773142672, 9.5546285344, 19.1092570688,
+    38.2185141376, 76.4370282752, 152.8740565504, 305.7481131008,
     611.4962262016, 1222.9924524032, 2445.9849048064, 4891.9698096128,
     9783.9396192256
 };
@@ -55,29 +55,24 @@ QPointF operator/(const QPointF& p1, const QPointF& p2)
 }
 
 
-IDrawContext::IDrawContext(const QString& name, CCanvas::redraw_e maskRedraw, CCanvas *parent)
+IDrawContext::IDrawContext(const QString& name, CCanvas::redraw_e maskRedraw, CCanvas* parent)
     : QThread(parent)
     , canvas(parent)
     , maskRedraw(maskRedraw)
 {
     setObjectName(name);
-    // setup map parameters and connect to canvas
-    pjsrc = pj_init_plus("+proj=merc +a=6378137.0000 +b=6356752.3142 +towgs84=0,0,0,0,0,0,0,0 +units=m  +no_defs");
-    pjtar = pj_init_plus("+proj=longlat +a=6378137.0000 +b=6356752.3142 +towgs84=0,0,0,0,0,0,0,0 +units=m  +no_defs");
 
-    setScales(CCanvas::eScalesDefault);
+    IDrawContext::setScales(CCanvas::eScalesDefault);
 
     zoom(5);
 
     resize(canvas->size());
     connect(this, &IDrawContext::finished, canvas, static_cast<void (CCanvas::*)()>(&CCanvas::update));
-    connect(this, &IDrawContext::finished, this,   &IDrawContext::sigStopThread);
+    connect(this, &IDrawContext::finished, this, &IDrawContext::sigStopThread);
 }
 
 IDrawContext::~IDrawContext()
 {
-    pj_free(pjtar);
-    pj_free(pjsrc);
 }
 
 void IDrawContext::emitSigCanvasUpdate()
@@ -102,13 +97,13 @@ bool IDrawContext::resize(const QSize& size)
 
     QMutexLocker lock(&mutex);
 
-    lastSize   = size;
-    viewWidth  = size.width();
+    lastSize = size;
+    viewWidth = size.width();
     viewHeight = size.height();
 
-    center     = QPointF(viewWidth / 2.0, viewHeight / 2.0);
-    bufWidth   = viewWidth  + 2 * BUFFER_BORDER;
-    bufHeight  = viewHeight + 2 * BUFFER_BORDER;
+    center = QPointF(viewWidth / 2.0, viewHeight / 2.0);
+    bufWidth = viewWidth + 2 * BUFFER_BORDER;
+    bufHeight = viewHeight + 2 * BUFFER_BORDER;
 
     buffer[0].image = QImage(bufWidth, bufHeight, QImage::Format_ARGB32);
     buffer[0].image.fill(Qt::transparent);
@@ -121,26 +116,13 @@ bool IDrawContext::resize(const QSize& size)
 
 QString IDrawContext::getProjection() const
 {
-    if(pjsrc == nullptr)
-    {
-        return QString::Null();
-    }
-
-    char *p = pj_get_def(pjsrc, 0);
-    QString str(p);
-    free(p);
-
-    return str;
+    return proj.getProjSrc();
 }
 
-void IDrawContext::setProjection(const QString& proj)
+bool IDrawContext::setProjection(const QString& projStr)
 {
-    if(pjsrc != nullptr)
-    {
-        pj_free(pjsrc);
-    }
-
-    pjsrc = pj_init_plus(proj.toLatin1());
+    proj.init(projStr.toLatin1(), "EPSG:4326");
+    return proj.isValid();
 }
 
 void IDrawContext::setScales(const CCanvas::scales_type_e type)
@@ -174,7 +156,7 @@ bool IDrawContext::needsRedraw() const
 
 void IDrawContext::zoom(const QRectF& rect)
 {
-    if(pjsrc == nullptr)
+    if(!proj.isValid())
     {
         return;
     }
@@ -206,7 +188,7 @@ void IDrawContext::zoom(const QRectF& rect)
 
 void IDrawContext::zoom(bool in, CCanvas::redraw_e& needsRedraw)
 {
-    if(pjsrc == nullptr)
+    if(!proj.isValid())
     {
         return;
     }
@@ -222,19 +204,19 @@ void IDrawContext::zoom(int idx)
     mutex.lock(); // --------- start serialize with thread
     if((zoomIndex != idx) || (zoomFactor.x() != scales[idx]))
     {
-        zoomIndex       = idx;
+        zoomIndex = idx;
         zoomFactor.rx() = scales[idx];
         zoomFactor.ry() = scales[idx];
-        intNeedsRedraw  = true;
+        intNeedsRedraw = true;
 
-        emit sigScaleChanged(scale*zoomFactor);
+        emit sigScaleChanged(scale* zoomFactor);
     }
     mutex.unlock(); // --------- stop serialize with thread
 }
 
-void IDrawContext::convertRad2M(QPointF &p) const
+void IDrawContext::convertRad2M(QPointF& p) const
 {
-    if(pjsrc == nullptr)
+    if(!proj.isValid())
     {
         return;
     }
@@ -249,7 +231,7 @@ void IDrawContext::convertRad2M(QPointF &p) const
     bool fixWest = p.x() < (-180 * DEG_TO_RAD);
     bool fixEast = p.x() > ( 180 * DEG_TO_RAD);
 
-    pj_transform(pjtar, pjsrc, 1, 0, &p.rx(), &p.ry(), 0);
+    proj.transform(p, PJ_INV);
 
     /*
         The idea of the fix is to calculate a point
@@ -271,17 +253,17 @@ void IDrawContext::convertRad2M(QPointF &p) const
     }
 }
 
-void IDrawContext::convertM2Rad(QPointF &p) const
+void IDrawContext::convertM2Rad(QPointF& p) const
 {
-    if(pjsrc == nullptr)
+    if(!proj.isValid())
     {
         return;
     }
 
-    pj_transform(pjsrc, pjtar, 1, 0, &p.rx(), &p.ry(), 0);
+    proj.transform(p, PJ_FWD);
 }
 
-void IDrawContext::convertPx2Rad(QPointF &p) const
+void IDrawContext::convertPx2Rad(QPointF& p) const
 {
     mutex.lock(); // --------- start serialize with thread
 
@@ -295,7 +277,7 @@ void IDrawContext::convertPx2Rad(QPointF &p) const
     mutex.unlock(); // --------- stop serialize with thread
 }
 
-void IDrawContext::convertRad2Px(QPointF &p) const
+void IDrawContext::convertRad2Px(QPointF& p) const
 {
     mutex.lock(); // --------- start serialize with thread
 
@@ -311,7 +293,7 @@ void IDrawContext::convertRad2Px(QPointF &p) const
 
 void IDrawContext::convertRad2Px(QPolygonF& poly) const
 {
-    if(pjsrc == nullptr)
+    if(!proj.isValid())
     {
         return;
     }
@@ -331,8 +313,8 @@ void IDrawContext::convertRad2Px(QPolygonF& poly) const
 
     QVector<p_t> fixes(N, {NOFLOAT, NOFLOAT});
 
-    qreal * pY  = &poly.data()->ry();
-    p_t * pFix  = fixes.data();
+    qreal* pY = &poly.data()->ry();
+    p_t* pFix = fixes.data();
 
     /*
         Proj4 makes a wrap around for values outside the
@@ -352,11 +334,10 @@ void IDrawContext::convertRad2Px(QPolygonF& poly) const
         }
     }
 
-    pj_transform(pjtar, pjsrc, N, 2, &poly.data()->rx(), &poly.data()->ry(), 0);
+    proj.transform(poly, PJ_INV);
 
-
-    QPointF * pPt = poly.data();
-    pFix          = fixes.data();
+    QPointF* pPt = poly.data();
+    pFix = fixes.data();
     for(int i = 0; i < N; ++i, ++pFix, ++pPt)
     {
         /*
@@ -386,7 +367,7 @@ void IDrawContext::convertRad2Px(QPolygonF& poly) const
 
 void IDrawContext::draw(QPainter& p, CCanvas::redraw_e needsRedraw, const QPointF& f)
 {
-    if(pjsrc == nullptr)
+    if(!proj.isValid())
     {
         return;
     }
@@ -404,8 +385,8 @@ void IDrawContext::draw(QPainter& p, CCanvas::redraw_e needsRedraw, const QPoint
     // derive references for all corners coordinate of map buffer
     ref1 = f1 + QPointF(-bufWidth / 2, -bufHeight / 2) * bufferScale;
     ref2 = f1 + QPointF( bufWidth / 2, -bufHeight / 2) * bufferScale;
-    ref3 = f1 + QPointF( bufWidth / 2,  bufHeight / 2) * bufferScale;
-    ref4 = f1 + QPointF(-bufWidth / 2,  bufHeight / 2) * bufferScale;
+    ref3 = f1 + QPointF( bufWidth / 2, bufHeight / 2) * bufferScale;
+    ref4 = f1 + QPointF(-bufWidth / 2, bufHeight / 2) * bufferScale;
     convertM2Rad(ref1);
     convertM2Rad(ref2);
     convertM2Rad(ref3);
@@ -482,15 +463,14 @@ void IDrawContext::run()
     {
         // copy all projection information need by the
         // map render objects to buffer structure
-        currentBuffer.pjsrc      = pjsrc;
         currentBuffer.zoomFactor = zoomFactor;
-        currentBuffer.scale      = scale;
-        currentBuffer.ref1       = ref1;
-        currentBuffer.ref2       = ref2;
-        currentBuffer.ref3       = ref3;
-        currentBuffer.ref4       = ref4;
-        currentBuffer.focus      = focus;
-        intNeedsRedraw           = false;
+        currentBuffer.scale = scale;
+        currentBuffer.ref1 = ref1;
+        currentBuffer.ref2 = ref2;
+        currentBuffer.ref3 = ref3;
+        currentBuffer.ref4 = ref4;
+        currentBuffer.focus = focus;
+        intNeedsRedraw = false;
 
         mutex.unlock();
 
