@@ -20,22 +20,22 @@
 #define IDRAWCONTEXT_H
 
 
-#include <proj_api.h>
+#include "canvas/CCanvas.h"
+#include "gis/proj_x.h"
+
 #include <QImage>
 #include <QMutex>
 #include <QPointF>
 #include <QThread>
 
 
-#include "canvas/CCanvas.h"
-
 #define CANVAS_MAX_ZOOM_LEVELS 31
 
 class IDrawContext : public QThread
 {
     Q_OBJECT
 public:
-    IDrawContext(const QString &name, CCanvas::redraw_e maskRedraw, CCanvas *parent);
+    IDrawContext(const QString& name, CCanvas::redraw_e maskRedraw, CCanvas* parent);
     virtual ~IDrawContext();
 
     struct buffer_t
@@ -43,10 +43,8 @@ public:
         /// @note: all coordinate values are long/lat WGS84 [rad]
 
         QImage image; //< the canvas buffer
-        projPJ pjsrc; //< the used projection
 
         int zoomLevels; //< the number of zoom levels
-
         QPointF zoomFactor {1.0, 1.0}; //< the zoomfactor used to draw the canvas
         QPointF scale {1.0, 1.0}; //< the scale of the global viewport
 
@@ -68,7 +66,7 @@ public:
        @param in            set true to zoom in, and false to zoom out
        @param needsRedraw   if the zoom action makes a redraw necessary needsRedraw is set true
      */
-    void zoom(bool in, CCanvas::redraw_e &needsRedraw);
+    void zoom(bool in, CCanvas::redraw_e& needsRedraw);
     void zoom(int idx);
     void zoom(const QRectF& rect);
     int  zoom() const
@@ -81,13 +79,13 @@ public:
        @note  The unit is dependent on the currently used projection and must not necessarily be meter
        @param p             the point to convert
      */
-    void convertRad2M(QPointF &p) const;
+    void convertRad2M(QPointF& p) const;
     /**
        @brief Convert a geo coordinate of the currently used projection/datum to lon/lat WGS84
        @note  The unit is dependent on the currently used projection and must not necessarily be meter
        @param p             the point to convert
      */
-    void convertM2Rad(QPointF &p) const;
+    void convertM2Rad(QPointF& p) const;
     /**
        @brief Convert a pixel coordinate from the viewport to a geo coordinate in [rad]
        @param p             the point to convert
@@ -112,7 +110,7 @@ public:
         @param needsRedraw  set true to trigger a redraw in the background thread
         @param f            the point of focus in [°] that is drawn in the middle of the viewport.
      */
-    void draw(QPainter& p, CCanvas::redraw_e needsRedraw, const QPointF &f);
+    void draw(QPainter& p, CCanvas::redraw_e needsRedraw, const QPointF& f);
 
     /**
        @brief Get the projection string of this map object
@@ -141,7 +139,7 @@ public:
 
        @param proj a Proj4 projection string
      */
-    virtual void setProjection(const QString& proj);
+    virtual bool setProjection(const QString& projStr);
 
     virtual void setScales(const CCanvas::scales_type_e type);
 
@@ -179,7 +177,7 @@ protected:
     bool intNeedsRedraw;
 
     /// the canvas this map object is attached to
-    CCanvas * canvas;
+    CCanvas* canvas;
 
     const CCanvas::redraw_e maskRedraw;
     /// map canvas twin buffer
@@ -187,24 +185,27 @@ protected:
     /// the main threads currently used map canvas buffer
     bool bufIndex = false;
 
-    int bufWidth   = 100; //< buffer width [px]
-    int bufHeight  = 100; //< buffer height [px]
-    int viewWidth  = 100; //< the viewports width [px]
+    int bufWidth = 100;   //< buffer width [px]
+    int bufHeight = 100;  //< buffer height [px]
+    int viewWidth = 100;  //< the viewports width [px]
     int viewHeight = 100; //< the viewports height [px]
 
     QSize lastSize;
 
     QPointF center; /// the center of the viewport
 
-    projPJ pjsrc; //< source projection should be the same for all maps
-    projPJ pjtar; //< target projection is always WGS84
+    /**
+        source projection should be the same for all maps
+        target projection is always EPSG:4326
+     */
+    CProj proj {"EPSG:3857", "EPSG:4326"};
 
     /// index into scales table
     int zoomIndex = 0;
 
 private:
     /// the used scales and the type of scale levels
-    const qreal *scales = nullptr;
+    const qreal* scales = nullptr;
     CCanvas::scales_type_e scalesType;
     /// the number of zoom levels
     int zoomLevels = 0;
