@@ -29,7 +29,7 @@ inline qint16 getValue(QVector<qint16>& data, int x, int y, int dx)
     return data[x + y * dx];
 }
 
-inline void fillWindow(QVector<qint16>& data, int x, int y, int dx, qint16 * w)
+inline void fillWindow(QVector<qint16>& data, int x, int y, int dx, qint16* w)
 {
     w[0] = getValue(data, x - 1, y - 1, dx);
     w[1] = getValue(data, x, y - 1, dx);
@@ -47,16 +47,16 @@ inline void fillWindow4x4(QVector<qint16>& data, qreal x, qreal y, int dx, qint1
     x = qFloor(x);
     y = qFloor(y);
 
-    w[0]  = getValue(data, x - 1, y - 1, dx);
-    w[1]  = getValue(data, x, y - 1, dx);
-    w[2]  = getValue(data, x + 1, y - 1, dx);
-    w[3]  = getValue(data, x + 2, y - 1, dx);
-    w[4]  = getValue(data, x - 1, y, dx);
-    w[5]  = getValue(data, x, y, dx);
-    w[6]  = getValue(data, x + 1, y, dx);
-    w[7]  = getValue(data, x + 2, y, dx);
-    w[8]  = getValue(data, x - 1, y + 1, dx);
-    w[9]  = getValue(data, x, y + 1, dx);
+    w[0] = getValue(data, x - 1, y - 1, dx);
+    w[1] = getValue(data, x, y - 1, dx);
+    w[2] = getValue(data, x + 1, y - 1, dx);
+    w[3] = getValue(data, x + 2, y - 1, dx);
+    w[4] = getValue(data, x - 1, y, dx);
+    w[5] = getValue(data, x, y, dx);
+    w[6] = getValue(data, x + 1, y, dx);
+    w[7] = getValue(data, x + 2, y, dx);
+    w[8] = getValue(data, x - 1, y + 1, dx);
+    w[9] = getValue(data, x, y + 1, dx);
     w[10] = getValue(data, x + 1, y + 1, dx);
     w[11] = getValue(data, x + 2, y + 1, dx);
     w[12] = getValue(data, x - 1, y + 2, dx);
@@ -73,17 +73,16 @@ const struct SlopePresets IDem::slopePresets[7]
     { "Grade 3 (DAV Snowcard)", {27.0, 29.0, 30.0, 31.0, 34.0}},
     { "Grade 4 (DAV Snowcard)", {23.0, 25.0, 27.0, 28.0, 30.0}},
 
-    { "level country",        { 3.0,  6.0,  8.0, 12.0, 15.0}},
-    { "secondary mountain",   { 4.0,  7.0, 10.0, 15.0, 20.0}},
-    { "lofty mountain",       {10.0, 15.0, 20.0, 30.0, 50.0}}
+    { "level country", { 3.0, 6.0, 8.0, 12.0, 15.0}},
+    { "secondary mountain", { 4.0, 7.0, 10.0, 15.0, 20.0}},
+    { "lofty mountain", {10.0, 15.0, 20.0, 30.0, 50.0}}
 };
 
-IDem::IDem(CDemDraw *parent)
+IDem::IDem(CDemDraw* parent)
     : IDrawObject(parent)
     , dem(parent)
 {
     slotSetOpacity(17);
-    pjtar = pj_init_plus("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs");
 
     graytable.resize(256);
     for(int i = 0; i < 255; i++)
@@ -105,49 +104,47 @@ IDem::IDem(CDemDraw *parent)
 
 IDem::~IDem()
 {
-    pj_free(pjtar);
-    pj_free(pjsrc);
 }
 
 void IDem::saveConfig(QSettings& cfg)
 {
     IDrawObject::saveConfig(cfg);
 
-    cfg.setValue("doHillshading",     bHillshading);
+    cfg.setValue("doHillshading", bHillshading);
     cfg.setValue("factorHillshading", factorHillshading);
-    cfg.setValue("doSlopeColor",      bSlopeColor);
+    cfg.setValue("doSlopeColor", bSlopeColor);
 
-    cfg.setValue("gradeSlopeColor",   gradeSlopeColor);
+    cfg.setValue("gradeSlopeColor", gradeSlopeColor);
     cfg.setValue("slopeCustomValue0", slopeCustomStepTable[0]);
     cfg.setValue("slopeCustomValue1", slopeCustomStepTable[1]);
     cfg.setValue("slopeCustomValue2", slopeCustomStepTable[2]);
     cfg.setValue("slopeCustomValue3", slopeCustomStepTable[3]);
     cfg.setValue("slopeCustomValue4", slopeCustomStepTable[4]);
 
-    cfg.setValue("doElevationLimit",  bElevationLimit);
-    cfg.setValue("elevationValue",    elevationValue);
+    cfg.setValue("doElevationLimit", bElevationLimit);
+    cfg.setValue("elevationValue", elevationValue);
 }
 
 void IDem::loadConfig(QSettings& cfg)
 {
     IDrawObject::loadConfig(cfg);
 
-    bHillshading      = cfg.value("doHillshading",     bHillshading     ).toBool();
+    bHillshading = cfg.value("doHillshading", bHillshading     ).toBool();
     factorHillshading = cfg.value("factorHillshading", factorHillshading).toFloat();
-    bSlopeColor       = cfg.value("doSlopeColor",      bSlopeColor      ).toBool();
-    gradeSlopeColor   = cfg.value("gradeSlopeColor",   gradeSlopeColor  ).toInt();
+    bSlopeColor = cfg.value("doSlopeColor", bSlopeColor      ).toBool();
+    gradeSlopeColor = cfg.value("gradeSlopeColor", gradeSlopeColor  ).toInt();
 
-    slopeCustomStepTable[0] = cfg.value("slopeCustomValue0",  5.).toFloat();
+    slopeCustomStepTable[0] = cfg.value("slopeCustomValue0", 5.).toFloat();
     slopeCustomStepTable[1] = cfg.value("slopeCustomValue1", 10.).toFloat();
     slopeCustomStepTable[2] = cfg.value("slopeCustomValue2", 15.).toFloat();
     slopeCustomStepTable[3] = cfg.value("slopeCustomValue3", 20.).toFloat();
     slopeCustomStepTable[4] = cfg.value("slopeCustomValue4", 25.).toFloat();
 
-    bElevationLimit = cfg.value("doElevationLimit",  bElevationLimit  ).toBool();
-    elevationValue  = cfg.value("elevationValue", 0).toInt();
+    bElevationLimit = cfg.value("doElevationLimit", bElevationLimit  ).toBool();
+    elevationValue = cfg.value("elevationValue", 0).toInt();
 }
 
-IDemProp * IDem::getSetup()
+IDemProp* IDem::getSetup()
 {
     if(setup.isNull())
     {
@@ -240,11 +237,11 @@ void IDem::hillshading(QVector<qint16>& data, qreal w, qreal h, QImage& img)
                 continue;
             }
 
-            qreal dx         = ((win[0] + win[3] + win[3] + win[6]) - (win[2] + win[5] + win[5] + win[8])) / (xscale * factorHillshading);
-            qreal dy         = ((win[6] + win[7] + win[7] + win[8]) - (win[0] + win[1] + win[1] + win[2])) / (yscale * factorHillshading);
-            qreal aspect     = qAtan2(dy, dx);
+            qreal dx = ((win[0] + win[3] + win[3] + win[6]) - (win[2] + win[5] + win[5] + win[8])) / (xscale * factorHillshading);
+            qreal dy = ((win[6] + win[7] + win[7] + win[8]) - (win[0] + win[1] + win[1] + win[2])) / (yscale * factorHillshading);
+            qreal aspect = qAtan2(dy, dx);
             qreal xx_plus_yy = dx * dx + dy * dy;
-            qreal cang       = (SIN_ALT - ZFACT_COS_ALT * qSqrt(xx_plus_yy) * qSin(aspect - AZ)) / qSqrt(1 + ZFACT_BY_ZFACT * xx_plus_yy);
+            qreal cang = (SIN_ALT - ZFACT_COS_ALT * qSqrt(xx_plus_yy) * qSin(aspect - AZ)) / qSqrt(1 + ZFACT_BY_ZFACT * xx_plus_yy);
 
             if (cang <= 0.0)
             {
@@ -298,15 +295,15 @@ qreal IDem::slopeOfWindowInterp(qint16* win2, winsize_e size, qreal x, qreal y)
         return NOFLOAT;
     }
 
-    qreal dx    = ((win[0] + win[3] + win[3] + win[6]) - (win[2] + win[5] + win[5] + win[8])) / (xscale);
-    qreal dy    = ((win[6] + win[7] + win[7] + win[8]) - (win[0] + win[1] + win[1] + win[2])) / (yscale);
-    qreal k     = dx * dx + dy * dy;
-    qreal slope =  qAtan(qSqrt(k) / (8 * 1.0)) * 180.0 / M_PI;
+    qreal dx = ((win[0] + win[3] + win[3] + win[6]) - (win[2] + win[5] + win[5] + win[8])) / (xscale);
+    qreal dy = ((win[6] + win[7] + win[7] + win[8]) - (win[0] + win[1] + win[1] + win[2])) / (yscale);
+    qreal k = dx * dx + dy * dy;
+    qreal slope = qAtan(qSqrt(k) / (8 * 1.0)) * 180.0 / M_PI;
 
     return slope;
 }
 
-void IDem::slopecolor(QVector<qint16>& data, qreal w, qreal h, QImage &img)
+void IDem::slopecolor(QVector<qint16>& data, qreal w, qreal h, QImage& img)
 {
     int wp2 = w + 2;
 
@@ -319,7 +316,7 @@ void IDem::slopecolor(QVector<qint16>& data, qreal w, qreal h, QImage &img)
             fillWindow(data, n, m, wp2, win);
             qreal slope = slopeOfWindowInterp(win, eWinsize3x3, 0, 0);
 
-            const qreal *currentSlopeStepTable = getCurrentSlopeStepTable();
+            const qreal* currentSlopeStepTable = getCurrentSlopeStepTable();
 
             if(slope > currentSlopeStepTable[4])
             {
@@ -349,7 +346,7 @@ void IDem::slopecolor(QVector<qint16>& data, qreal w, qreal h, QImage &img)
     }
 }
 
-void IDem::elevationLimit(QVector<qint16>& data, qreal w, qreal h, QImage &img)
+void IDem::elevationLimit(QVector<qint16>& data, qreal w, qreal h, QImage& img)
 {
     int wp2 = w + 2;
 
@@ -389,5 +386,5 @@ void IDem::elevationLimit(QVector<qint16>& data, qreal w, qreal h, QImage &img)
 
 void IDem::drawTile(QImage& img, QPolygonF& l, QPainter& p)
 {
-    drawTileLQ(img, l, p, *dem, pjsrc, pjtar);
+    drawTileLQ(img, l, p, *dem, proj);
 }
