@@ -39,7 +39,7 @@ class CGisListWks : public QTreeWidget
 {
     Q_OBJECT
 public:
-    CGisListWks(QWidget * parent);
+    CGisListWks(QWidget* parent);
     virtual ~CGisListWks();
 
     enum column_e
@@ -52,15 +52,15 @@ public:
     };
 
 
-    void setExternalMenu(QMenu * project);
-    bool hasProject(IGisProject *project);
+    void setExternalMenu(QMenu* project);
+    bool hasProject(IGisProject* project);
 
-    IGisProject * getProjectByKey(const QString& key);
-    CDBProject * getProjectById(quint64 id, const QString& db);
+    IGisProject* getProjectByKey(const QString& key);
+    CDBProject* getProjectById(quint64 id, const QString& db);
 
-    bool event(QEvent * e) override;
+    bool event(QEvent* e) override;
 
-    void addProject(IGisProject *proj);
+    void addProject(IGisProject* proj);
 
     void removeDevice(const QString& key);
 
@@ -72,8 +72,8 @@ signals:
     void sigItemDeleted();
 
 protected:
-    void dragMoveEvent(QDragMoveEvent *e) override;
-    void dropEvent(QDropEvent     *e) override;
+    void dragMoveEvent(QDragMoveEvent* e) override;
+    void dropEvent(QDropEvent* e) override;
 
 private slots:
     void slotSaveWorkspace();
@@ -86,8 +86,8 @@ private slots:
     void slotDeleteProject();
     void slotShowOnMap();
     void slotHideFrMap();
-    void slotItemDoubleClicked(QTreeWidgetItem * item, int);
-    void slotItemChanged(QTreeWidgetItem * item, int column);
+    void slotItemDoubleClicked(QTreeWidgetItem* item, int);
+    void slotItemChanged(QTreeWidgetItem* item, int column);
     void slotEditItem();
     void slotTagItem();
     void slotDeleteItem();
@@ -128,7 +128,11 @@ private slots:
     void slotEleWptTrk();
     void slotAutoSaveProject(bool on);
     void slotUserFocusPrj(bool yes);
+    void slotAutoSyncProject(bool yes);
     void slotAddProjectFilter();
+    void slotNewDevice();
+    void slotSyncPrjToDevices();
+    void slotToRoute();
 
 private:
     void configDB();
@@ -138,25 +142,36 @@ private:
     void migrateDB2to3();
     void migrateDB3to4();
     void setVisibilityOnMap(bool visible);
-    QAction * addSortAction(QObject *parent, QActionGroup *actionGroup, const QString& icon, const QString& text, IGisProject::sorting_folder_e mode);
-    QAction * addAction(const QIcon& icon, const QString& name, QObject * parent, const char * slot);
+    QAction* addSortAction(QObject* parent, QActionGroup* actionGroup, const QString& icon, const QString& text, IGisProject::sorting_folder_e mode);
 
-    void showMenuProjectWks(const QPoint &p);
-    void showMenuProjectDev(const QPoint &p);
-    void showMenuProjectTrash(const QPoint &p);
-    void showMenuItemTrk(const QPoint &p, const IGisItem::key_t& key);
-    void showMenuItemWpt(const QPoint &p, CGisItemWpt *wpt);
-    void showMenuItemRte(const QPoint &p);
-    void showMenuItemOvl(const QPoint &p);
-    void showMenuItem(const QPoint &p, const QList<IGisItem::key_t> &keysTrks, const QList<IGisItem::key_t> &keysWpts);
+    template<typename Func>
+    QAction* addAction(const QIcon& icon, const QString& name, QObject* parent, Func slot)
+    {
+        QAction* action = new QAction(icon, name, parent);
+        connect(action, &QAction::triggered, this, slot);
+        return action;
+    }
+
+    void showMenuProjectWks(const QPoint& p);
+    void showMenuProjectDev(const QPoint& p);
+    void showMenuProjectTrash(const QPoint& p);
+    void showMenuItemTrk(const QPoint& p, const IGisItem::key_t& key);
+    void showMenuItemWpt(const QPoint& p, CGisItemWpt* wpt);
+    void showMenuItemRte(const QPoint& p);
+    void showMenuItemOvl(const QPoint& p);
+    void showMenuItem(const QPoint& p, const QList<IGisItem::key_t>& keysTrks, const QList<IGisItem::key_t>& keysWpts);
+
+    void syncPrjToDevices(IGisProject* project, const QSet<QString>& keys);
+    QSet<QString> getAllDeviceKeys() const;
 
     template<typename T>
-    QList<IGisItem::key_t> selectedItems2Keys()
+    QList<IGisItem::key_t> selectedItems2Keys() const
     {
         QList<IGisItem::key_t> keys;
-        for(QTreeWidgetItem * item : selectedItems())
+        const QList<QTreeWidgetItem*>& items = selectedItems();
+        for(const QTreeWidgetItem* item : items)
         {
-            T * gisItem = dynamic_cast<T*>(item);
+            const T* gisItem = dynamic_cast<const T*>(item);
             if(nullptr != gisItem)
             {
                 keys << gisItem->getKey();
@@ -167,65 +182,67 @@ private:
 
     QSqlDatabase db;
 
-    QActionGroup * actionGroupSort;
-    QAction * actionSave;
-    QAction * actionSaveAs;
-    QAction * actionSaveAsStrict;
-    QAction * actionAutoSave;
-    QAction * actionUserFocusPrj;
-    QAction * actionCopyPrj;
-    QAction * actionEditPrj;
-    QAction * actionCloseProj;
-    QAction * actionShowOnMap;
-    QAction * actionHideFrMap;
-    QAction * actionSyncWksDev;
-    QAction * actionSyncDB;
-    QAction * actionSortByTime;
-    QAction * actionSortByName;
-    QAction * actionSortByRating;
-    QAction * actionFilterProject;
-    QAction * actionDelProj;
-    QAction * actionSyncDevWks;
-    QAction * actionEditDetails;
-    QAction * actionTagItem;
-    QAction * actionCopyItem;
-    QAction * actionDelete;
-    QAction * actionBubbleWpt;
-    QAction * actionDelRadiusWpt;
-    QAction * actionNogoWpt;
-    QAction * actionEditRadiusWpt;
-    QAction * actionProjWpt;
-    QAction * actionMoveWpt;
-    QAction * actionCopyCoordWpt;
-    QAction * actionFocusTrk;
-    QAction * actionEditTrk;
-    QAction * actionReverseTrk;
-    QAction * actionCombineTrk;
-    QAction * actionRangeTrk;
-    QAction * actionNogoTrk;
-    QAction * actionCopyTrkWithWpt;
-    QAction * actionFocusRte;
-    QAction * actionCalcRte;
-    QAction * actionResetRte;
-    QAction * actionEditRte;
-    QAction * actionNogoRte;
-    QAction * actionReverseRte;
-    QAction * actionRte2Trk;
-    QAction * actionEditArea;
-    QAction * actionNogoArea;
-    QAction * actionRteFromWpt;
-    QAction * actionEditPrxWpt;
+    QActionGroup* actionGroupSort;
+    QAction* actionSave;
+    QAction* actionSaveAs;
+    QAction* actionSaveAsStrict;
+    QAction* actionAutoSave;
+    QAction* actionUserFocusPrj;
+    QAction* actionAutoSyncToDev;
+    QAction* actionCopyPrj;
+    QAction* actionEditPrj;
+    QAction* actionCloseProj;
+    QAction* actionShowOnMap;
+    QAction* actionHideFrMap;
+    QAction* actionSyncWksDev;
+    QAction* actionSyncDB;
+    QAction* actionSortByTime;
+    QAction* actionSortByName;
+    QAction* actionSortByRating;
+    QAction* actionFilterProject;
+    QAction* actionDelProj;
+    QAction* actionSyncDevWks;
+    QAction* actionEditDetails;
+    QAction* actionTagItem;
+    QAction* actionCopyItem;
+    QAction* actionDelete;
+    QAction* actionBubbleWpt;
+    QAction* actionDelRadiusWpt;
+    QAction* actionNogoWpt;
+    QAction* actionEditRadiusWpt;
+    QAction* actionProjWpt;
+    QAction* actionMoveWpt;
+    QAction* actionCopyCoordWpt;
+    QAction* actionFocusTrk;
+    QAction* actionEditTrk;
+    QAction* actionReverseTrk;
+    QAction* actionCombineTrk;
+    QAction* actionRangeTrk;
+    QAction* actionNogoTrk;
+    QAction* actionCopyTrkWithWpt;
+    QAction* actionFocusRte;
+    QAction* actionCalcRte;
+    QAction* actionResetRte;
+    QAction* actionEditRte;
+    QAction* actionNogoRte;
+    QAction* actionReverseRte;
+    QAction* actionRte2Trk;
+    QAction* actionEditArea;
+    QAction* actionNogoArea;
+    QAction* actionRteFromWpt;
+    QAction* actionEditPrxWpt;
+    QAction* actionToRoute;
 
-    QAction * actionEleWptTrk;
+    QAction* actionEleWptTrk;
 
-    QMenu * menuNone = nullptr;
+    QMenu* menuNone = nullptr;
 
     QPointer<CGeoSearch> geoSearch;
 
     bool saveOnExit = true;
     qint32 saveEvery = 5;
 
-    IDeviceWatcher * deviceWatcher = nullptr;
+    IDeviceWatcher* deviceWatcher = nullptr;
 
     bool blockSorting = false;
 };
