@@ -19,16 +19,34 @@
 #ifndef POI_H
 #define POI_H
 
+#include "IGisItem.h"
 #include "units/IUnit.h"
+#include <QPointF>
+#include <QSize>
 
 struct poi_t
 {
     poi_t() : pos(NOPOINTF){}
     QString name;
     QString desc;
+    /// in radians
     QPointF pos;
-    QSize symbolSize;
+    QString icon;
+    QList<IGisItem::link_t> links;
+    quint32 ele = NOINT;
 };
 
+inline bool operator==(const poi_t& poi1, const poi_t& poi2)
+{
+    return poi1.name == poi2.name
+           && poi1.desc == poi2.desc
+           && poi1.pos == poi2.pos;
+}
+
+inline uint qHash(const poi_t& poi, uint seed)
+{
+    return qHash(poi.name, seed) ^ qHash(poi.desc, seed) ^ qHash(poi.pos.x(), seed) ^ qHash(poi.pos.y(), seed);
+}
+
 #endif //POI_H
 
