@@ -18,6 +18,27 @@
 
 #include "gis/fit/defs/CFitBaseType.h"
 
+const CFitBaseType fit::EnumType = CFitBaseType(eBaseTypeNrEnum, "Enum", sizeof(quint8), {0xFF});
+const CFitBaseType fit::Sint8Type = CFitBaseType(eBaseTypeNrSint8, "Sint8", sizeof(qint8), {0x7F});
+const CFitBaseType fit::Uint8Type = CFitBaseType(eBaseTypeNrUint8, "Uint8", sizeof(quint8), {0xFF});
+const CFitBaseType fit::Sint16Type = CFitBaseType(eBaseTypeNrSint16, "Sint16", sizeof(qint16), {0x7F, 0xFF});
+const CFitBaseType fit::Uint16Type = CFitBaseType(eBaseTypeNrUint16, "Uint16", sizeof(quint16), {0xFF, 0xFF});
+const CFitBaseType fit::Sint32Type = CFitBaseType(eBaseTypeNrSint32, "Sint32", sizeof(qint32), {0x7F, 0xFF, 0xFF, 0xFF});
+const CFitBaseType fit::Uint32Type = CFitBaseType(eBaseTypeNrUint32, "Uint32", sizeof(quint32), {0xFF, 0xFF, 0xFF, 0xFF});
+const CFitBaseType fit::Sint64Type = CFitBaseType(eBaseTypeNrSint64, "Sint64", sizeof(qint64), {0x7F, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF});
+const CFitBaseType fit::Uint64Type = CFitBaseType(eBaseTypeNrUint64, "Uint64", sizeof(quint64), {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF});
+const CFitBaseType fit::StringType = CFitBaseType(eBaseTypeNrString, "String", 0, {0x00}); // Field is invalid if all bytes are invalid.
+const CFitBaseType fit::Float32Type = CFitBaseType(eBaseTypeNrFloat32, "Float32", sizeof(float), {0xFF, 0xFF, 0xFF, 0xFF});
+const CFitBaseType fit::Float64Type = CFitBaseType(eBaseTypeNrFloat64, "Float64", sizeof(double), {0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF});
+const CFitBaseType fit::Uint8zType = CFitBaseType(eBaseTypeNrUint8z, "Uint8z", sizeof(quint8), {0x00});
+const CFitBaseType fit::Uint16zType = CFitBaseType(eBaseTypeNrUint16z, "Uint16z", sizeof(quint16), {0x00, 0x00});
+const CFitBaseType fit::Uint32zType = CFitBaseType(eBaseTypeNrUint32z, "Uint32z", sizeof(quint32), {0x00, 0x00, 0x00, 0x00});
+const CFitBaseType fit::Uint64zType = CFitBaseType(eBaseTypeNrUint64z, "Uint64z", sizeof(quint64), {0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00, 0x00});
+const CFitBaseType fit::ByteType = CFitBaseType(eBaseTypeNrByte, "Byte", 0, {0xFF}); // Field is invalid if all bytes are invalid.
+const CFitBaseType fit::InvalidType = CFitBaseType(eBaseTypeNrInvalid, "Invalid", 0, {0});
+
+
+
 CFitBaseType::CFitBaseType() : CFitBaseType(eBaseTypeNrInvalid, "invalid", 0,
 {
     0
@@ -117,23 +138,23 @@ QString CFitBaseType::name() const
 
 void CFitBaseTypeMap::initialize(QMap<quint8, CFitBaseType>& baseTypesMap)
 {
-    baseTypesMap.insert(fitEnumType.nr(), fitEnumType);
-    baseTypesMap.insert(fitSint8Type.nr(), fitSint8Type);
-    baseTypesMap.insert(fitUint8Type.nr(), fitUint8Type);
-    baseTypesMap.insert(fitSint16Type.nr(), fitSint16Type);
-    baseTypesMap.insert(fitUint16Type.nr(), fitUint16Type);
-    baseTypesMap.insert(fitSint32Type.nr(), fitSint32Type);
-    baseTypesMap.insert(fitUint32Type.nr(), fitUint32Type);
-    baseTypesMap.insert(fitSint64Type.nr(), fitSint64Type);
-    baseTypesMap.insert(fitUint64Type.nr(), fitUint64Type);
-    baseTypesMap.insert(fitStringType.nr(), fitStringType);
-    baseTypesMap.insert(fitFloat32Type.nr(), fitFloat32Type);
-    baseTypesMap.insert(fitFloat64Type.nr(), fitFloat64Type);
-    baseTypesMap.insert(fitUint8zType.nr(), fitUint8zType);
-    baseTypesMap.insert(fitUint16zType.nr(), fitUint16zType);
-    baseTypesMap.insert(fitUint32zType.nr(), fitUint32zType);
-    baseTypesMap.insert(fitUint64zType.nr(), fitUint64zType);
-    baseTypesMap.insert(fitByteType.nr(), fitByteType);
+    baseTypesMap.insert(fit::EnumType.nr(), fit::EnumType);
+    baseTypesMap.insert(fit::Sint8Type.nr(), fit::Sint8Type);
+    baseTypesMap.insert(fit::Uint8Type.nr(), fit::Uint8Type);
+    baseTypesMap.insert(fit::Sint16Type.nr(), fit::Sint16Type);
+    baseTypesMap.insert(fit::Uint16Type.nr(), fit::Uint16Type);
+    baseTypesMap.insert(fit::Sint32Type.nr(), fit::Sint32Type);
+    baseTypesMap.insert(fit::Uint32Type.nr(), fit::Uint32Type);
+    baseTypesMap.insert(fit::Sint64Type.nr(), fit::Sint64Type);
+    baseTypesMap.insert(fit::Uint64Type.nr(), fit::Uint64Type);
+    baseTypesMap.insert(fit::StringType.nr(), fit::StringType);
+    baseTypesMap.insert(fit::Float32Type.nr(), fit::Float32Type);
+    baseTypesMap.insert(fit::Float64Type.nr(), fit::Float64Type);
+    baseTypesMap.insert(fit::Uint8zType.nr(), fit::Uint8zType);
+    baseTypesMap.insert(fit::Uint16zType.nr(), fit::Uint16zType);
+    baseTypesMap.insert(fit::Uint32zType.nr(), fit::Uint32zType);
+    baseTypesMap.insert(fit::Uint64zType.nr(), fit::Uint64zType);
+    baseTypesMap.insert(fit::ByteType.nr(), fit::ByteType);
 }
 
 CFitBaseType* CFitBaseTypeMap::get(quint8 nr)
