@@ -24,22 +24,22 @@
 #include <QtWidgets>
 
 
-static const QList<extension_t> extensions =
+const QList<extension_t> CLogProject::extensions =
 {
-    {"Latitude",           0.0000001,      0.0,        ASSIGN_VALUE(lat, NIL)}   // unit [°]
-    , {"Longitude",          0.0000001,      0.0,        ASSIGN_VALUE(lon, NIL)}  // unit [°]
-    , {"Altitude",           1.0,            0.0,        ASSIGN_VALUE(ele, NIL)}  // unit [m]
-    , {"VerticalSpeed",      0.01,           0.0,        ASSIGN_VALUE(extensions["gpxdata:verticalSpeed"], NIL)}                  // unit [m/h]
-    , {"HR",                 1.0,            0.0,        ASSIGN_VALUE(extensions["gpxtpx:TrackPointExtension|gpxtpx:hr"], qRound)}   // unit [bpm]
-    , {"Cadence",            1.0,            0.0,        ASSIGN_VALUE(extensions["gpxdata:cadence"], NIL)}                        // unit [bpm]
-    , {"Temperature",        0.1,            0.0,        ASSIGN_VALUE(extensions["gpxdata:temp"], NIL)}                           // unit [°C]
-    , {"SeaLevelPressure",   0.1,            0.0,        ASSIGN_VALUE(extensions["gpxdata:seaLevelPressure"], NIL)}               // unit [hPa]
-    , {"Speed",              0.01,           0.0,        ASSIGN_VALUE(extensions["gpxdata:speed"], NIL)}                          // unit [m/s]
-    , {"EnergyConsumption",  0.1,            0.0,        ASSIGN_VALUE(extensions["gpxdata:energy"], NIL)}                         // unit [kCal/min]
+    {"Latitude", 0.0000001, 0.0, ASSIGN_VALUE(lat, NIL)}                         // unit [°]
+    , {"Longitude", 0.0000001, 0.0, ASSIGN_VALUE(lon, NIL)}                       // unit [°]
+    , {"Altitude", 1.0, 0.0, ASSIGN_VALUE(ele, NIL)}                              // unit [m]
+    , {"VerticalSpeed", 0.01, 0.0, ASSIGN_VALUE(extensions["gpxdata:verticalSpeed"], NIL)}                                        // unit [m/h]
+    , {"HR", 1.0, 0.0, ASSIGN_VALUE(extensions["gpxtpx:TrackPointExtension|gpxtpx:hr"], qRound)}                                     // unit [bpm]
+    , {"Cadence", 1.0, 0.0, ASSIGN_VALUE(extensions["gpxdata:cadence"], NIL)}                                                     // unit [bpm]
+    , {"Temperature", 0.1, 0.0, ASSIGN_VALUE(extensions["gpxdata:temp"], NIL)}                                                    // unit [°C]
+    , {"SeaLevelPressure", 0.1, 0.0, ASSIGN_VALUE(extensions["gpxdata:seaLevelPressure"], NIL)}                                   // unit [hPa]
+    , {"Speed", 0.01, 0.0, ASSIGN_VALUE(extensions["gpxdata:speed"], NIL)}                                                        // unit [m/s]
+    , {"EnergyConsumption", 0.1, 0.0, ASSIGN_VALUE(extensions["gpxdata:energy"], NIL)}                                            // unit [kCal/min]
 };
 
 
-CLogProject::CLogProject(const QString &filename, CGisListWks * parent)
+CLogProject::CLogProject(const QString& filename, CGisListWks* parent)
     : ISuuntoProject(eTypeLog, filename, parent)
 {
     setIcon(CGisListWks::eColumnIcon, QIcon("://icons/32x32/LogProject.png"));
@@ -56,7 +56,7 @@ void CLogProject::loadLog(const QString& filename)
     {
         loadLog(filename, this);
     }
-    catch(QString &errormsg)
+    catch(QString& errormsg)
     {
         QMessageBox::critical(CMainWindow::getBestWidgetForParent(),
                               tr("Failed to load file %1...").arg(filename), errormsg, QMessageBox::Abort);
@@ -65,7 +65,7 @@ void CLogProject::loadLog(const QString& filename)
 }
 
 
-void CLogProject::loadLog(const QString &filename, CLogProject *project)
+void CLogProject::loadLog(const QString& filename, CLogProject* project)
 {
     QFile file(filename);
 
@@ -110,7 +110,7 @@ void CLogProject::loadLog(const QString &filename, CLogProject *project)
         const QDomNode& xmlDeviceInfo = xmlOpenambitlog.namedItem("DeviceInfo");
         if(xmlDeviceInfo.namedItem("Name").isElement())
         {
-            trk.cmt =  tr("Device: %1<br/>").arg(xmlDeviceInfo.namedItem("Name").toElement().text());
+            trk.cmt = tr("Device: %1<br/>").arg(xmlDeviceInfo.namedItem("Name").toElement().text());
         }
     }
 
@@ -227,7 +227,7 @@ void CLogProject::loadLog(const QString &filename, CLogProject *project)
                                  || xmlSample.namedItem("Type").toElement().text() == "position"
                                  || xmlSample.namedItem("Type").toElement().text() == "periodic")
                         {
-                            for (const extension_t& ext  : extensions)
+                            for (const extension_t& ext : extensions)
                             {
                                 if (xmlSample.namedItem(ext.tag).isElement())
                                 {
