@@ -73,7 +73,7 @@ void CGisItemWpt::saveTCX(QDomNode& courseNode, const QDateTime crsPtDateTimeToB
 
 void CGisItemTrk::saveTCXcourse(QDomNode& coursesNode)
 {
-    IGisProject * project = getParentProject();
+    IGisProject* project = getParentProject();
     if (nullptr == project)
     {
         return;
@@ -132,7 +132,7 @@ void CGisItemTrk::saveTCXcourse(QDomNode& coursesNode)
         {
             eleToBeWritten = trkpt.ele;    // take elevation on the trackpoint
         }
-        CGisItemWpt * wpt = dynamic_cast<CGisItemWpt*>(project->getItemByKey(trkpt.keyWpt));
+        CGisItemWpt* wpt = dynamic_cast<CGisItemWpt*>(project->getItemByKey(trkpt.keyWpt));
         if (nullptr != wpt)   // if trackpoint has an attached waypoint
         {
             wptKeys << trkpt.keyWpt; // store attached waypoint
@@ -168,9 +168,9 @@ void CGisItemTrk::saveTCXcourse(QDomNode& coursesNode)
     }
 
     int i = 0;
-    for (const IGisItem::key_t& wptKey : wptKeys)  // browse course points
+    for (const IGisItem::key_t& wptKey : qAsConst(wptKeys))  // browse course points
     {
-        CGisItemWpt *wptItem = dynamic_cast<CGisItemWpt*>(project->getItemByKey(wptKey));
+        CGisItemWpt* wptItem = dynamic_cast<CGisItemWpt*>(project->getItemByKey(wptKey));
         wptItem->saveTCX(courseNode, trkPtToOverwriteDateTimes[i++]);
     }
 }
@@ -178,7 +178,7 @@ void CGisItemTrk::saveTCXcourse(QDomNode& coursesNode)
 
 void CGisItemTrk::saveTCXactivity(QDomNode& activitiesNode)
 {
-    IGisProject * project = getParentProject();
+    IGisProject* project = getParentProject();
     if (nullptr == project)
     {
         return;
@@ -194,7 +194,7 @@ void CGisItemTrk::saveTCXactivity(QDomNode& activitiesNode)
     activityNode.appendChild(doc.createElement("Id"));
     activityNode.lastChild().appendChild(doc.createTextNode(trk.segs[0].pts[0].time.toString("yyyy-MM-dd'T'hh:mm:ss'Z'")));
 
-    for (const CTrackData::trkseg_t &seg : trk.segs)
+    for (const CTrackData::trkseg_t& seg : qAsConst(trk.segs))
     {
         QDomElement lapElmt = doc.createElement("Lap");
         activityNode.appendChild(lapElmt);
@@ -219,7 +219,7 @@ void CGisItemTrk::saveTCXactivity(QDomNode& activitiesNode)
         QDomElement xmlTrk = doc.createElement("Track");
         lapElmt.appendChild(xmlTrk);
 
-        for (const CTrackData::trkpt_t &trkpt : seg.pts)
+        for (const CTrackData::trkpt_t& trkpt : seg.pts)
         {
             QDomElement xmlTrkpt = doc.createElement("Trackpoint");
             xmlTrk.appendChild(xmlTrkpt);
