@@ -23,7 +23,7 @@
 #include <QMessageBox>
 #include <QtWidgets>
 
-CInvalidTrk::CInvalidTrk(CGisItemTrk &trk, QWidget *parent)
+CInvalidTrk::CInvalidTrk(CGisItemTrk& trk, QWidget* parent)
     : QDialog(parent)
     , trk(trk)
 {
@@ -35,14 +35,14 @@ CInvalidTrk::CInvalidTrk(CGisItemTrk &trk, QWidget *parent)
     int s = QApplication::style()->pixelMetric(QStyle::PM_MessageBoxIconSize);
     labelIcon->setPixmap( QApplication::style()->standardIcon(QStyle::SP_MessageBoxQuestion).pixmap(s, s));
 
-    IGisProject * p = trk.getParentProject();
+    IGisProject* p = trk.getParentProject();
     if(p != nullptr && !p->getName().isEmpty())
     {
         labelName->setText("<b>" + p->getName() + ":</b>");
     }
 
     labelMsg->setText(tr("The track '%1' has %2 invalid points out of %3 visible points. "
-                         "Do you want to hide invalid points now?")
+                         "Do you want to remove invalid points now?")
                       .arg(trk.getName())
                       .arg(trk.getNumberOfInvalidPoints())
                       .arg(trk.getNumberOfVisiblePoints()));
@@ -80,7 +80,7 @@ void CInvalidTrk::slotShowDetails()
 
 void CInvalidTrk::slotDoNotAskAgain(bool checked)
 {
-    IGisProject * project = trk.getParentProject();
+    IGisProject* project = trk.getParentProject();
     if(project != nullptr)
     {
         project->setInvalidDataOk(checked);
