@@ -1,10 +1,11 @@
 #ifndef TRACKDATA_H
 #define TRACKDATA_H
 
+#include "gis/GeoMath.h"
 #include "gis/IGisItem.h"
-#include "GeoMath.h"
+#include "gis/proj_x.h"
+
 #include <functional>
-#include <proj_api.h>
 #include <QPoint>
 #include <QtWidgets>
 
@@ -23,17 +24,17 @@ public:
 
         void reset()
         {
-            deltaDistance   = NOFLOAT;
-            distance        = NOFLOAT;
-            ascent          = NOFLOAT;
-            descent         = NOFLOAT;
-            elapsedSeconds  = NOFLOAT;
+            deltaDistance = NOFLOAT;
+            distance = NOFLOAT;
+            ascent = NOFLOAT;
+            descent = NOFLOAT;
+            elapsedSeconds = NOFLOAT;
             elapsedSecondsMoving = NOFLOAT;
-            slope1          = NOFLOAT;
-            slope2          = NOFLOAT;
-            speed           = NOFLOAT;
-            idxVisible      = NOIDX;
-            valid           = 0;
+            slope1 = NOFLOAT;
+            slope2 = NOFLOAT;
+            speed = NOFLOAT;
+            idxVisible = NOIDX;
+            valid = 0;
         }
 
         enum flag_e
@@ -101,9 +102,9 @@ public:
 
         enum invalid_e
         {
-            eInvalidTime  = eValidTime  << 16
-            , eInvalidEle  = eValidEle   << 16
-            , eInvalidPos  = eValidPos   << 16
+            eInvalidTime  = eValidTime << 16
+            , eInvalidEle  = eValidEle << 16
+            , eInvalidPos  = eValidPos << 16
             , eInvalidSlope= eValidSlope << 16
             , eInvalidMask = 0xFFFF0000
         };
@@ -171,7 +172,7 @@ public:
             return QPointF(lon * DEG_TO_RAD, lat * DEG_TO_RAD);
         }
 
-        inline qreal distanceTo(const trkpt_t &other)
+        inline qreal distanceTo(const trkpt_t& other)
         {
             return GPS_Math_Distance(lon * DEG_TO_RAD, lat * DEG_TO_RAD, other.lon * DEG_TO_RAD, other.lat * DEG_TO_RAD);
         }
@@ -222,7 +223,7 @@ public:
 
     CTrackData() {}
 
-    CTrackData(const QString &name, const CTrackData &other, qint32 rangeStart, qint32 rangeEnd);
+    CTrackData(const QString& name, const CTrackData& other, qint32 rangeStart, qint32 rangeEnd);
 
     // -- all gpx tags - start
     QString name;
@@ -238,11 +239,25 @@ public:
 
     void removeEmptySegments();
 
-    void readFrom(const SGisLine &l);
-    void readFrom(const QVector<trkpt_t> &pts);
-    void getPolyline(SGisLine  &l) const;
-    void getPolyline(QPolygonF &l) const;
-    void getPolylineDeg(QPolygonF &l) const;
+    void readFrom(const SGisLine& l);
+    void readFrom(const QVector<trkpt_t>& pts);
+    void getPolyline(SGisLine& l) const;
+    void getPolyline(QPolygonF& l) const;
+    void getPolylineDeg(QPolygonF& l) const;
+    /**
+           @brief Convert a track to a line.
+           Convert a track between rangeStart and rangeEnd to a line. If getSubPixel is true all sub-pixels
+           are converted to a point. Otherwise the sub-pixels are ignored.
+
+           @param l Converted Polyline.
+           @param rangeStart Start index of the conversion. If set to NOIDX, conversion starts at
+                  the beginning of the track.
+           @param rangeEnd End index of the conversion. If set to NOIDX, conversion end at
+                  the last point of the track.
+           @param getSubPixel If getSubPixel is true all sub-pixels are converted to a point.
+                  If set to false the sub-pixels are ignored.
+    */
+    void getPolylineRange(SGisLine& l, qint32 rangeStart, qint32 rangeEnd, bool getSubPixel = false) const;
 
     bool isEmpty() const
     {
@@ -269,7 +284,7 @@ public:
        @param idx The index into all visible points
        @return A null pointer of no point is found.
      */
-    const trkpt_t *getTrkPtByVisibleIndex(qint32 idx) const;
+    const trkpt_t* getTrkPtByVisibleIndex(qint32 idx) const;
     /**
        @brief Try to get access Nth point
 
@@ -279,8 +294,8 @@ public:
        @param idx The index into all points
        @return A null pointer of no point is found.
      */
-    const trkpt_t *getTrkPtByTotalIndex(qint32 idx) const;
-    trkpt_t *getTrkPtByTotalIndex(qint32 idx);
+    const trkpt_t* getTrkPtByTotalIndex(qint32 idx) const;
+    trkpt_t* getTrkPtByTotalIndex(qint32 idx);
 
     /**
        @brief Check if the track point at index it the last one visible
@@ -293,7 +308,7 @@ public:
 
     bool delTrkPtDesc(const QList<int>& idxTotal);
 
-    const trkpt_t * last() const
+    const trkpt_t* last() const
     {
         if(segs.isEmpty() || segs.last().isEmpty())
         {
@@ -305,11 +320,11 @@ public:
     template<typename T1, typename T2>
     class iterator : public std::iterator<std::forward_iterator_tag, T2>
     {
-        T1 &trk;
+        T1& trk;
         int seg = 0;
-        int pt  = 0;
+        int pt = 0;
 public:
-        explicit iterator(T1 &trk, int seg, int pt) : trk(trk), seg(seg), pt(pt) {}
+        explicit iterator(T1& trk, int seg, int pt) : trk(trk), seg(seg), pt(pt) {}
 
         iterator& operator++()
         {
@@ -348,10 +363,10 @@ public:
         }
     };
 
-    iterator<CTrackData, trkpt_t> begin() { return iterator<CTrackData, trkpt_t>(*this,            0, 0); }
+    iterator<CTrackData, trkpt_t> begin() { return iterator<CTrackData, trkpt_t>(*this, 0, 0); }
     iterator<CTrackData, trkpt_t> end()   { return iterator<CTrackData, trkpt_t>(*this, segs.count(), 0); }
 
-    iterator<const CTrackData, const trkpt_t> begin() const { return iterator<const CTrackData, const trkpt_t>(*this,            0, 0); }
+    iterator<const CTrackData, const trkpt_t> begin() const { return iterator<const CTrackData, const trkpt_t>(*this, 0, 0); }
     iterator<const CTrackData, const trkpt_t> end()   const { return iterator<const CTrackData, const trkpt_t>(*this, segs.count(), 0); }
 };
 
