@@ -21,7 +21,7 @@
 
 #include <QtWidgets>
 
-CFilterSpeedCycle::CFilterSpeedCycle(QWidget *parent, CGisItemTrk &trk)
+CFilterSpeedCycle::CFilterSpeedCycle(QWidget* parent, CGisItemTrk& trk)
     : QWidget(parent), trk(trk), noOfFixTypes(4), noOfCustomTypes(3)
     // 4 fix and 3 custom cycling types has be defined as default
     , cyclingTypeDefaults
@@ -68,7 +68,7 @@ CFilterSpeedCycle::CFilterSpeedCycle(QWidget *parent, CGisItemTrk &trk)
     cycling_type_t cyclingType;
     for (int i = 0; i < noOfFixTypes; ++i)
     {
-        const cycling_type_t &cyclingTypeDefault = cyclingTypeDefaults[i];
+        const cycling_type_t& cyclingTypeDefault = cyclingTypeDefaults[i];
         cyclingType.name = cyclingTypeDefault.name;
         cyclingType.plainSpeed = cyclingTypeDefault.plainSpeed;
         cyclingType.minSpeed = cyclingTypeDefault.minSpeed;
@@ -80,13 +80,13 @@ CFilterSpeedCycle::CFilterSpeedCycle(QWidget *parent, CGisItemTrk &trk)
         cyclingTypes << cyclingType;
     }
 
-    connect(comboCyclingType, SIGNAL(activated(int)), this, SLOT(slotSetCyclingType(int)));
-    connect(spinPlainSpeed, SIGNAL(valueChanged(double)), this, SLOT(slotSetPlainSpeed(double)));
-    connect(spinMinSpeed, SIGNAL(valueChanged(double)), this, SLOT(slotSetMinSpeed(double)));
-    connect(spinSlopeAtMinSpeed, SIGNAL(valueChanged(double)), this, SLOT(slotSetSlopeAtMinSpeed(double)));
-    connect(spinMaxSpeed, SIGNAL(valueChanged(double)), this, SLOT(slotSetMaxSpeed(double)));
-    connect(spinSlopeAtMaxSpeed, SIGNAL(valueChanged(double)), this, SLOT(slotSetSlopeAtMaxSpeed(double)));
-    connect(pushSetMinMaxSlope, SIGNAL(clicked(bool)), this, SLOT(slotSetMinMaxSlopes(bool)));
+    connect(comboCyclingType, static_cast<void (QComboBox::*)(int)>(&QComboBox::activated), this, &CFilterSpeedCycle::slotSetCyclingType);
+    connect(spinPlainSpeed, static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this, &CFilterSpeedCycle::slotSetPlainSpeed);
+    connect(spinMinSpeed, static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this, &CFilterSpeedCycle::slotSetMinSpeed);
+    connect(spinSlopeAtMinSpeed, static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this, &CFilterSpeedCycle::slotSetSlopeAtMinSpeed);
+    connect(spinMaxSpeed, static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this, &CFilterSpeedCycle::slotSetMaxSpeed);
+    connect(spinSlopeAtMaxSpeed, static_cast<void (QDoubleSpinBox::*)(double)>(&QDoubleSpinBox::valueChanged), this, &CFilterSpeedCycle::slotSetSlopeAtMaxSpeed);
+    connect(pushSetMinMaxSlope, &QPushButton::clicked, this, &CFilterSpeedCycle::slotSetMinMaxSlopes);
 }
 
 void CFilterSpeedCycle::loadSettings(QSettings& cfg)
@@ -95,7 +95,7 @@ void CFilterSpeedCycle::loadSettings(QSettings& cfg)
     cfg.beginReadArray("CustomCyclingTypes");
     for (int i = 0; i < noOfCustomTypes; ++i)
     {
-        const cycling_type_t &cyclingTypeDefault = cyclingTypeDefaults[noOfFixTypes + i];
+        const cycling_type_t& cyclingTypeDefault = cyclingTypeDefaults[noOfFixTypes + i];
         cfg.setArrayIndex(i);
         cyclingType.name = cyclingTypeDefault.name;
         cyclingType.plainSpeed = cfg.value("plainSpeed", cyclingTypeDefault.plainSpeed).toDouble();
@@ -119,7 +119,7 @@ void CFilterSpeedCycle::saveSettings(QSettings& cfg)
     cfg.beginWriteArray("CustomCyclingTypes");
     for (int i = 0; i < noOfCustomTypes; ++i)
     {
-        const cycling_type_t &cyclingType = cyclingTypes[noOfFixTypes + i];
+        const cycling_type_t& cyclingType = cyclingTypes[noOfFixTypes + i];
         cfg.setArrayIndex(i);
         cfg.setValue("name", cyclingType.name);
         cfg.setValue("plainSpeed", cyclingType.plainSpeed);
@@ -138,7 +138,7 @@ void CFilterSpeedCycle::apply(CGisItemTrk& trk)
 
 void CFilterSpeedCycle::slotSetCyclingType(int type)
 {
-    const cycling_type_t &cyclingType = cyclingTypes[type];
+    const cycling_type_t& cyclingType = cyclingTypes[type];
 
     spinPlainSpeed->setValue(cyclingType.plainSpeed);
     spinMinSpeed->setValue(cyclingType.minSpeed);
