@@ -19,7 +19,8 @@
 #ifndef CGRID_H
 #define CGRID_H
 
-#include <proj_api.h>
+#include "gis/proj_x.h"
+
 #include <QColor>
 #include <QObject>
 class QPainter;
@@ -30,29 +31,28 @@ class CGrid : public QObject
 {
     Q_OBJECT
 public:
-    CGrid(CMapDraw * map);
+    CGrid(CMapDraw* map);
     virtual ~CGrid();
 
     void saveConfig(QSettings& cfg);
     void loadConfig(QSettings& cfg);
 
-    void draw(QPainter& p, const QRect &rect);
+    void draw(QPainter& p, const QRect& rect);
 
-    void setProjAndColor(const QString& proj, const QColor& c);
+    void setProjAndColor(const QString& projStr, const QColor& c);
+
+    const QColor& getColor(){return color;}
+    const QString getGridProjString(){return proj.getProjTar();}
 
     void convertPos2Str(const QPointF& pos, QString& info, bool simple);
 
 private:
-    friend class CGridSetup;
     void findGridSpace(qreal min, qreal max, qreal& xSpace, qreal& ySpace);
     bool calcIntersection(qreal x1, qreal y1, qreal x2, qreal y2, qreal x3, qreal y3, qreal x4, qreal y4, qreal& x, qreal& y);
 
-    CMapDraw * map;
+    CMapDraw* map;
 
-    projPJ pjWGS84 = nullptr;
-    projPJ pjGrid  = nullptr;
-
-    QString projstr = "+proj=longlat +datum=WGS84 +no_defs";
+    CProj proj {"EPSG:4326", "EPSG:4326"};
     QColor color = Qt::magenta;
 };
 
