@@ -23,7 +23,6 @@
 #include "units/IUnit.h"
 
 #include <gdal_priv.h>
-#include <ogr_spatialref.h>
 #include <QtWidgets>
 
 #define TILELIMIT 2500
@@ -31,7 +30,7 @@
 #define TILESIZEY 64
 
 
-CMapVRT::CMapVRT(const QString &filename, CMapDraw *parent)
+CMapVRT::CMapVRT(const QString& filename, CMapDraw* parent)
     : IMap(eFeatVisibility, parent)
     , filename(filename)
 {
@@ -50,7 +49,7 @@ CMapVRT::CMapVRT(const QString &filename, CMapDraw *parent)
     rasterBandCount = dataset->GetRasterCount();
     if(rasterBandCount == 1)
     {
-        GDALRasterBand *pBand = dataset->GetRasterBand(1);
+        GDALRasterBand* pBand = dataset->GetRasterBand(1);
 
         if(nullptr == pBand)
         {
@@ -60,16 +59,16 @@ CMapVRT::CMapVRT(const QString &filename, CMapDraw *parent)
             return;
         }
 
-        if(pBand->GetColorInterpretation() ==  GCI_PaletteIndex )
+        if(pBand->GetColorInterpretation() == GCI_PaletteIndex )
         {
-            GDALColorTable * pct = pBand->GetColorTable();
+            GDALColorTable* pct = pBand->GetColorTable();
             for(int i = 0; i < pct->GetColorEntryCount(); ++i)
             {
                 const GDALColorEntry& e = *pct->GetColorEntry(i);
                 colortable << qRgba(e.c1, e.c2, e.c3, e.c4);
             }
         }
-        else if(pBand->GetColorInterpretation() ==  GCI_GrayIndex )
+        else if(pBand->GetColorInterpretation() == GCI_GrayIndex )
         {
             for(int i = 0; i < 256; ++i)
             {
@@ -118,22 +117,9 @@ CMapVRT::CMapVRT(const QString &filename, CMapDraw *parent)
 
 
     // ------- setup projection ---------------
-    char str[1025] = {0};
-    if(dataset->GetProjectionRef())
-    {
-        strncpy(str, dataset->GetProjectionRef(), sizeof(str) - 1);
-    }
+    proj.init(dataset->GetProjectionRef(), "EPSG:4326");
 
-    OGRSpatialReference oSRS;
-    const char *wkt = str;
-    oSRS.importFromWkt(&wkt);
-
-    char *proj4 = nullptr;
-    oSRS.exportToProj4(&proj4);
-    pjsrc = pj_init_plus(proj4);
-    free(proj4);
-
-    if(pjsrc == 0)
+    if(!proj.isValid())
     {
         delete dataset;
         dataset = nullptr;
@@ -148,10 +134,10 @@ CMapVRT::CMapVRT(const QString &filename, CMapDraw *parent)
     qreal adfGeoTransform[6];
     dataset->GetGeoTransform( adfGeoTransform );
 
-    xscale  = adfGeoTransform[1];
-    yscale  = adfGeoTransform[5];
-    xrot    = adfGeoTransform[4];
-    yrot    = adfGeoTransform[2];
+    xscale = adfGeoTransform[1];
+    yscale = adfGeoTransform[5];
+    xrot = adfGeoTransform[4];
+    yrot = adfGeoTransform[2];
 
     trFwd.translate(adfGeoTransform[0], adfGeoTransform[3]);
     trFwd.scale(adfGeoTransform[1], adfGeoTransform[5]);
@@ -161,7 +147,7 @@ CMapVRT::CMapVRT(const QString &filename, CMapDraw *parent)
         trFwd.rotate(qAtan(adfGeoTransform[2] / adfGeoTransform[4]));
     }
 
-    if(pj_is_latlong(pjsrc))
+    if(proj.isSrcLatLong())
     {
         // convert to RAD to match internal notations
         trFwd = trFwd * DEG_TO_RAD;
@@ -256,7 +242,7 @@ bool CMapVRT::testForOverviews(const QString& filename)
         return false;
     }
 
-    for(const QString& file : files)
+    for(const QString& file : qAsConst(files))
     {
         using pGDALDataset = QSharedPointer<GDALDataset>;
         pGDALDataset _dataset = pGDALDataset((GDALDataset*)GDALOpen(file.toUtf8(), GA_ReadOnly), GDALClose);
@@ -299,10 +285,10 @@ void CMapVRT::draw(IDrawContext::buffer_t& buf) /* override */
     QPointF pt3 = ref3;
     QPointF pt4 = ref4;
 
-    pj_transform(pjsrc, pjtar, 1, 0, &pt1.rx(), &pt1.ry(), 0);
-    pj_transform(pjsrc, pjtar, 1, 0, &pt2.rx(), &pt2.ry(), 0);
-    pj_transform(pjsrc, pjtar, 1, 0, &pt3.rx(), &pt3.ry(), 0);
-    pj_transform(pjsrc, pjtar, 1, 0, &pt4.rx(), &pt4.ry(), 0);
+    proj.transform(pt1, PJ_FWD);
+    proj.transform(pt2, PJ_FWD);
+    proj.transform(pt3, PJ_FWD);
+    proj.transform(pt4, PJ_FWD);
 
     QPolygonF boundingBox;
     boundingBox << pt1 << pt2 << pt3 << pt4;
@@ -318,10 +304,10 @@ void CMapVRT::draw(IDrawContext::buffer_t& buf) /* override */
     pt3 = buf.ref3;
     pt4 = buf.ref4;
 
-    pj_transform(pjtar, pjsrc, 1, 0, &pt1.rx(), &pt1.ry(), 0);
-    pj_transform(pjtar, pjsrc, 1, 0, &pt2.rx(), &pt2.ry(), 0);
-    pj_transform(pjtar, pjsrc, 1, 0, &pt3.rx(), &pt3.ry(), 0);
-    pj_transform(pjtar, pjsrc, 1, 0, &pt4.rx(), &pt4.ry(), 0);
+    proj.transform(pt1, PJ_INV);
+    proj.transform(pt2, PJ_INV);
+    proj.transform(pt3, PJ_INV);
+    proj.transform(pt4, PJ_INV);
 
     pt1 = trInv.map(pt1);
     pt2 = trInv.map(pt2);
@@ -329,10 +315,10 @@ void CMapVRT::draw(IDrawContext::buffer_t& buf) /* override */
     pt4 = trInv.map(pt4);
 
     qreal left, right, top, bottom;
-    left     = pt1.x() < pt4.x() ? pt1.x() : pt4.x();
-    right    = pt2.x() > pt3.x() ? pt2.x() : pt3.x();
-    top      = pt1.y() < pt2.y() ? pt1.y() : pt2.y();
-    bottom   = pt4.y() > pt3.y() ? pt4.y() : pt3.y();
+    left = pt1.x() < pt4.x() ? pt1.x() : pt4.x();
+    right = pt2.x() > pt3.x() ? pt2.x() : pt3.x();
+    top = pt1.y() < pt2.y() ? pt1.y() : pt2.y();
+    bottom = pt4.y() > pt3.y() ? pt4.y() : pt3.y();
 
     if(left < 0)
     {
@@ -345,11 +331,11 @@ void CMapVRT::draw(IDrawContext::buffer_t& buf) /* override */
 
     if(top < 0)
     {
-        top  = 0;
+        top = 0;
     }
     if(top > ysize_px)
     {
-        top  = ysize_px;
+        top = ysize_px;
     }
 
     if(right > xsize_px)
@@ -370,10 +356,10 @@ void CMapVRT::draw(IDrawContext::buffer_t& buf) /* override */
         bottom = 0;
     }
 
-    qreal imgw = TILESIZEX;
-    qreal imgh = TILESIZEY;
-    qreal dx =  imgw;
-    qreal dy =  imgh;
+    qint32 imgw = TILESIZEX;
+    qint32 imgh = TILESIZEY;
+    qint32 dx = imgw;
+    qint32 dy = imgh;
 
 
     // estimate number of tiles and use it as a limit if no
@@ -407,14 +393,14 @@ void CMapVRT::draw(IDrawContext::buffer_t& buf) /* override */
     // limit number of tiles to keep performance
     if(!isOutOfScale(bufferScale) && (nTiles < TILELIMIT))
     {
-        for(qreal y = top; y < bottom; y += dy)
+        for(qint32 y = top; y < bottom; y += dy)
         {
             if(map->needsRedraw())
             {
                 break;
             }
 
-            for(qreal x = left; x < right; x += dx)
+            for(qint32 x = left; x < right; x += dx)
             {
                 if(map->needsRedraw())
                 {
@@ -425,28 +411,26 @@ void CMapVRT::draw(IDrawContext::buffer_t& buf) /* override */
                 CPLErr err = CE_Failure;
 
                 // reduce tile size at the border of the file
-                qreal dx_used   = dx;
-                qreal dy_used   = dy;
+                qreal dx_used = dx;
+                qreal dy_used = dy;
                 qreal imgw_used = imgw;
                 qreal imgh_used = imgh;
 
                 if((x + dx) > xsize_px)
                 {
-                    dx_used     = xsize_px - x;
-                    imgw_used   = qRound(imgw * dx_used / dx) & 0xFFFFFFFC;
+                    dx_used = xsize_px - x;
+                    imgw_used = qRound(imgw * dx_used / dx) & 0xFFFFFFFC;
                 }
                 if((y + dy) > ysize_px)
                 {
-                    dy_used     = ysize_px - y;
-                    imgh_used   = imgh * dy_used / dy;
+                    dy_used = ysize_px - y;
+                    imgh_used = imgh * dy_used / dy;
                 }
 
-                x           = qRound(x);
-                y           = qRound(y);
-                dx_used     = qFloor(dx_used);
-                dy_used     = qFloor(dy_used);
-                imgw_used   = qRound(imgw_used);
-                imgh_used   = qRound(imgh_used);
+                dx_used = qFloor(dx_used);
+                dy_used = qFloor(dy_used);
+                imgw_used = qRound(imgw_used);
+                imgh_used = qRound(imgh_used);
 
                 if(imgw_used < 1 || imgh_used < 1)
                 {
@@ -456,7 +440,7 @@ void CMapVRT::draw(IDrawContext::buffer_t& buf) /* override */
                 QImage img;
                 if(rasterBandCount == 1)
                 {
-                    GDALRasterBand * pBand;
+                    GDALRasterBand* pBand;
                     pBand = dataset->GetRasterBand(1);
 
                     img = QImage(QSize(imgw_used, imgh_used), QImage::Format_Indexed8);
@@ -474,13 +458,13 @@ void CMapVRT::draw(IDrawContext::buffer_t& buf) /* override */
                     img = QImage(imgw_used, imgh_used, QImage::Format_ARGB32);
                     img.fill(qRgba(255, 255, 255, 255));
 
-                    QVector<quint8> buffer(imgw_used * imgh_used);
+                    QVector<quint8> buffer(imgw_used* imgh_used);
 
                     QRgb testPix = qRgba(GCI_RedBand, GCI_GreenBand, GCI_BlueBand, GCI_AlphaBand);
 
                     for(int b = 1; b <= rasterBandCount; ++b)
                     {
-                        GDALRasterBand * pBand;
+                        GDALRasterBand* pBand;
                         pBand = dataset->GetRasterBand(b);
 
                         err = pBand->RasterIO(GF_Read
@@ -495,14 +479,14 @@ void CMapVRT::draw(IDrawContext::buffer_t& buf) /* override */
                             int pbandColour = pBand->GetColorInterpretation();
                             unsigned int offset;
 
-                            for (offset = 0; offset < sizeof(testPix) && *(((quint8 *)&testPix) + offset) != pbandColour; offset++)
+                            for (offset = 0; offset < sizeof(testPix) && *(((quint8*)&testPix) + offset) != pbandColour; offset++)
                             {
                             }
                             if(offset < sizeof(testPix))
                             {
-                                quint8 * pTar   = img.bits() + offset;
-                                quint8 * pSrc   = buffer.data();
-                                const int size  = buffer.size();
+                                quint8* pTar = img.bits() + offset;
+                                quint8* pSrc = buffer.data();
+                                const int size = buffer.size();
 
                                 for(int i = 0; i < size; ++i)
                                 {
@@ -525,10 +509,7 @@ void CMapVRT::draw(IDrawContext::buffer_t& buf) /* override */
                 l << QPointF(x, y) << QPointF(x + dx_used, y) << QPointF(x + dx_used, y + dy_used) << QPointF(x, y + dy_used);
                 l = trFwd.map(l);
 
-                pj_transform(pjsrc, pjtar, 1, 0, &l[0].rx(), &l[0].ry(), 0);
-                pj_transform(pjsrc, pjtar, 1, 0, &l[1].rx(), &l[1].ry(), 0);
-                pj_transform(pjsrc, pjtar, 1, 0, &l[2].rx(), &l[2].ry(), 0);
-                pj_transform(pjsrc, pjtar, 1, 0, &l[3].rx(), &l[3].ry(), 0);
+                proj.transform(l, PJ_FWD);
 
                 drawTile(img, l, p);
             }
