@@ -23,18 +23,15 @@
 
 #include <QtWidgets>
 
-IMap::IMap(quint32 features, CMapDraw *parent)
+IMap::IMap(quint32 features, CMapDraw* parent)
     : IDrawObject(parent)
     , map(parent)
     , flagsFeature(features)
 {
-    pjtar = pj_init_plus("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs");
 }
 
 IMap::~IMap()
 {
-    pj_free(pjtar);
-    pj_free(pjsrc);
     delete setup;
 }
 
@@ -44,15 +41,15 @@ void IMap::saveConfig(QSettings& cfg) /* override */
 
     if(hasFeatureVectorItems())
     {
-        cfg.setValue("showPolygons",  getShowPolygons());
+        cfg.setValue("showPolygons", getShowPolygons());
         cfg.setValue("showPolylines", getShowPolylines());
-        cfg.setValue("showPOIs",      getShowPOIs());
+        cfg.setValue("showPOIs", getShowPOIs());
         cfg.setValue("adjustDetailLevel", getAdjustDetailLevel());
     }
 
     if(hasFeatureTileCache())
     {
-        cfg.setValue("cacheSizeMB",     cacheSizeMB);
+        cfg.setValue("cacheSizeMB", cacheSizeMB);
         cfg.setValue("cacheExpiration", cacheExpiration);
     }
 
@@ -75,7 +72,7 @@ void IMap::loadConfig(QSettings& cfg) /* override */
     slotSetTypeFile(cfg.value("typeFile", getTypeFile()).toString());
 }
 
-IMapProp *IMap::getSetup()
+IMapProp* IMap::getSetup()
 {
     if(setup.isNull())
     {
@@ -86,22 +83,14 @@ IMapProp *IMap::getSetup()
 }
 
 
-void IMap::convertRad2M(QPointF &p) const
+void IMap::convertRad2M(QPointF& p) const
 {
-    if(pjsrc == nullptr)
-    {
-        return;
-    }
-    pj_transform(pjtar, pjsrc, 1, 0, &p.rx(), &p.ry(), 0);
+    proj.transform(p, PJ_INV);
 }
 
-void IMap::convertM2Rad(QPointF &p) const
+void IMap::convertM2Rad(QPointF& p) const
 {
-    if(pjsrc == nullptr)
-    {
-        return;
-    }
-    pj_transform(pjsrc, pjtar, 1, 0, &p.rx(), &p.ry(), 0);
+    proj.transform(p, PJ_FWD);
 }
 
 
@@ -112,6 +101,6 @@ bool IMap::findPolylineCloseBy(const QPointF&, const QPointF&, qint32, QPolygonF
 
 void IMap::drawTile(const QImage& img, QPolygonF& l, QPainter& p)
 {
-    drawTileLQ(img, l, p, *map, pjsrc, pjtar);
+    drawTileLQ(img, l, p, *map, proj);
 }
 
