@@ -29,13 +29,13 @@
 #include <QtWidgets>
 
 
-CMouseRangeTrk::CMouseRangeTrk(CGisItemTrk &trk, CGisDraw *gis, CCanvas *canvas, CMouseAdapter *mouse)
+CMouseRangeTrk::CMouseRangeTrk(CGisItemTrk& trk, CGisDraw* gis, CCanvas* canvas, CMouseAdapter* mouse)
     : IMouse(gis, canvas, mouse)
     , owner("CMouseRangeTrk")
 {
     setObjectName(owner);
-    cursor      = QCursor(QPixmap("://cursors/cursorSelectRange.png"), 0, 0);
-    key         = trk.getKey();
+    cursor = QCursor(QPixmap("://cursors/cursorSelectRange.png"), 0, 0);
+    key = trk.getKey();
 
     // switch to full mode to show deleted (hidden) track points, too
     trk.setMode(CGisItemTrk::eModeRange, owner);
@@ -43,22 +43,16 @@ CMouseRangeTrk::CMouseRangeTrk(CGisItemTrk &trk, CGisDraw *gis, CCanvas *canvas,
     scrOptRangeTool = new CScrOptRangeTool(trk, this, canvas);
 
     const QString& msg = QString("<b>%1</b><p>%2</p><p>%3</p><p>%4</p>")
-                         .arg(tr("Select Range"))
-                         .arg(tr(
-                                  "Select a first track point with left mouse button "
-                                  "and then a second one. Leave the range selection "
-                                  "with a click of the right mouse button."
-                                  ))
-                         .arg(tr(
-                                  "As an alternative you can use the buttons of the "
-                                  "range tool to move the start and end point of a "
-                                  "range. If you keep the buttons pressed the action "
-                                  "will be repeated."
-                                  ))
-                         .arg(tr(
-                                  "When you are done with the selection you can apply "
-                                  "one of the operations of the range tool. "
-                                  ));
+                         .arg(tr("Select Range"),
+                              tr("Select a first track point with left mouse button "
+                                 "and then a second one. Leave the range selection "
+                                 "with a click of the right mouse button."),
+                              tr("As an alternative you can use the buttons of the "
+                                 "range tool to move the start and end point of a "
+                                 "range. If you keep the buttons pressed the action "
+                                 "will be repeated."),
+                              tr("When you are done with the selection you can apply "
+                                 "one of the operations of the range tool. "));
 
     canvas->reportStatus(key.item, msg);
     canvas->slotTriggerCompleteUpdate(CCanvas::eRedrawGis);
@@ -68,7 +62,7 @@ CMouseRangeTrk::~CMouseRangeTrk()
 {
     canvas->reportStatus(key.item, "");
 
-    CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(CGisWorkspace::self().getItemByKey(key));
+    CGisItemTrk* trk = dynamic_cast<CGisItemTrk*>(CGisWorkspace::self().getItemByKey(key));
     if(trk)
     {
         trk->setMode(CGisItemTrk::eModeNormal, owner);
@@ -78,7 +72,7 @@ CMouseRangeTrk::~CMouseRangeTrk()
     delete scrOptRangeTool;
 }
 
-void CMouseRangeTrk::draw(QPainter& p,  CCanvas::redraw_e, const QRect &)
+void CMouseRangeTrk::draw(QPainter& p, CCanvas::redraw_e, const QRect&)
 {
     if(!scrOptRangeTool.isNull())
     {
@@ -95,7 +89,7 @@ void CMouseRangeTrk::leftButtonDown(const QPoint& pos)
 
 void CMouseRangeTrk::mouseMoved(const QPoint& pos)
 {
-    CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(CGisWorkspace::self().getItemByKey(key));
+    CGisItemTrk* trk = dynamic_cast<CGisItemTrk*>(CGisWorkspace::self().getItemByKey(key));
     if(trk == nullptr)
     {
         return;
@@ -116,7 +110,7 @@ void CMouseRangeTrk::mouseMoved(const QPoint& pos)
 
 void CMouseRangeTrk::leftClicked(const QPoint& point)
 {
-    CGisItemTrk * trk = dynamic_cast<CGisItemTrk*>(CGisWorkspace::self().getItemByKey(key));
+    CGisItemTrk* trk = dynamic_cast<CGisItemTrk*>(CGisWorkspace::self().getItemByKey(key));
     if(trk == nullptr)
     {
         return;
