@@ -31,12 +31,13 @@ class CMouseSelect : public IMouseSelect
 {
     Q_OBJECT
 public:
-    CMouseSelect(CGisDraw * gis, CCanvas * canvas, CMouseAdapter * mouse);
+    CMouseSelect(CGisDraw* gis, CCanvas* canvas, CMouseAdapter* mouse);
     virtual ~CMouseSelect();
 
-    void draw(QPainter& p, CCanvas::redraw_e needsRedraw, const QRect &rect) override;
+    void draw(QPainter& p, CCanvas::redraw_e needsRedraw, const QRect& rect) override;
 
 private slots:
+    void slotUpdate();
     void slotCopy() const;
     void slotRoute() const;
     void slotEditPrxWpt() const;
@@ -55,17 +56,23 @@ private:
 
        @param items a temporary list to collect all item pointers
      */
-    void findItems(QList<IGisItem *> &items);
+    void findItems(QList<IGisItem*>& items);
 
 
     QList<IGisItem::key_t> itemKeys;
-    IGisItem::selflags_t modeLastSel   = IGisItem::eSelectionNone;
+    static QMutex mutex;
+    QSet<poi_t> poisFound;
+    ///The POIs can be clustered together, so the icon is not necessarily displayed where the POI is.
+    /// Thus the location where to draw the highlight is separately given
+    QList<QPointF> posPoiHighlight;
+    IGisItem::selflags_t modeLastSel = IGisItem::eSelectionNone;
     QRectF rectLastSel;
 
     quint32 cntWpt = 0;
     quint32 cntTrk = 0;
     quint32 cntRte = 0;
     quint32 cntOvl = 0;
+    quint32 cntPoi = 0;
 };
 
 #endif //CMOUSESELECT_H
