@@ -23,31 +23,14 @@
 
 #include <QtWidgets>
 
-ITrack::ITrack()
-{
-    pjtar = pj_init_plus("+proj=longlat +ellps=WGS84 +datum=WGS84 +no_defs");
-}
-
-ITrack::~ITrack()
-{
-    if(pjtar)
-    {
-        pj_free(pjtar);
-    }
-    if(pjsrc)
-    {
-        pj_free(pjsrc);
-    }
-}
-
-void ITrack::save(QImage& image, const CTrackData::trkpt_t * pTrkpt)
+void ITrack::save(QImage& image, const CTrackData::trkpt_t* pTrkpt)
 {
     setSize(image.width(), image.height());
     draw();
     if(pTrkpt != nullptr)
     {
-        QPointF pos(pTrkpt->lon * DEG_TO_RAD, pTrkpt->lat * DEG_TO_RAD);
-        pj_transform(pjtar, pjsrc, 1, 0, &pos.rx(), &pos.ry(), 0);
+        QPointF pos(pTrkpt->lon* DEG_TO_RAD, pTrkpt->lat* DEG_TO_RAD);
+        proj.transform(pos, PJ_INV);
 
         QPainter p(&buffer);
         USE_ANTI_ALIASING(p, true);
@@ -68,27 +51,21 @@ void ITrack::setSize(int w, int h)
 
 void ITrack::setupProjection(const QRectF& boundingBox)
 {
-    if(pjsrc)
-    {
-        pj_free(pjsrc);
-        pjsrc = nullptr;
-    }
-
     if(boundingBox.top() > (60 * DEG_TO_RAD))
     {
-        pjsrc = pj_init_plus("+init=epsg:32661");
+        proj.init("EPSG:32661", "EPSG:4326");
     }
     else if(boundingBox.bottom() < (-60 * DEG_TO_RAD))
     {
-        pjsrc = pj_init_plus("+init=epsg:32761");
+        proj.init("EPSG:32761", "EPSG:4326");
     }
     else
     {
-        pjsrc = pj_init_plus("+init=epsg:3857");
+        proj.init("EPSG:3857", "EPSG:4326");
     }
 }
 
-void ITrack::setTrack(CGisItemTrk * track)
+void ITrack::setTrack(CGisItemTrk* track)
 {
     trk = track;
 
@@ -108,7 +85,7 @@ void ITrack::setTrack(const QPolygonF& track)
 
 void ITrack::updateData()
 {
-    if((pjsrc == nullptr) || (nullptr == trk && coords.isEmpty()))
+    if(!proj.isValid() || (nullptr == trk && coords.isEmpty()))
     {
         return;
     }
@@ -129,10 +106,10 @@ void ITrack::updateData()
     }
 
     line.clear();
-    for(const QPointF &trkpt : coords)
+    for(const QPointF& trkpt : qAsConst(coords))
     {
         QPointF pt(trkpt.x(), trkpt.y());
-        pj_transform(pjtar, pjsrc, 1, 0, &pt.rx(), &pt.ry(), 0);
+        proj.transform(pt, PJ_INV);
         line << pt;
     }
 
@@ -159,7 +136,7 @@ void ITrack::updateData()
         yoff = 0;
     }
 
-    xoff += r1.left()   - 5 / scale.x();
+    xoff += r1.left() - 5 / scale.x();
     yoff += r1.bottom() - 5 / scale.y();
 
     needsRedraw = true;
