@@ -17,15 +17,15 @@
 
 **********************************************************************************************/
 #include "CMainWindow.h"
-#include "GeoMath.h"
+#include "gis/GeoMath.h"
+#include "gis/proj_x.h"
 #include "units/CUnitAviation.h"
 #include "units/CUnitImperial.h"
 #include "units/CUnitMetric.h"
 #include "units/CUnitNautic.h"
 
-#include <proj_api.h>
 #include <QtWidgets>
-const IUnit * IUnit::m_self = nullptr;
+const IUnit* IUnit::m_self = nullptr;
 
 const QPointF NOPOINTF(NOFLOAT, NOFLOAT);
 const QPoint NOPOINT (NOINT, NOINT);
@@ -37,7 +37,7 @@ bool IUnit::useShortFormat = false;
 
 IUnit::slope_mode_e IUnit::slopeMode = IUnit::eSlopeDegrees;
 
-const char * IUnit::tblTimezone[] =
+const char* IUnit::tblTimezone[] =
 {
     "Africa/Abidjan",
     "Africa/Accra",
@@ -434,7 +434,7 @@ const QRegExp IUnit::reCoord4("^\\s*([N|S]){1}\\s*([0-9]+)\\W+([0-9]+)\\W+([0-9]
 
 const QRegExp IUnit::reCoord5("^\\s*([-0-9]+\\.[0-9]+)([N|S])\\s+([-0-9]+\\.[0-9]+)([W|E])\\s*$");
 
-IUnit::IUnit(const type_e &type, const QString& baseUnit, const qreal baseFactor, const QString& speedUnit, const qreal speedFactor, const QString &elevationUnit, const qreal elevationFactor, QObject * parent)
+IUnit::IUnit(const type_e& type, const QString& baseUnit, const qreal baseFactor, const QString& speedUnit, const qreal speedFactor, const QString& elevationUnit, const qreal elevationFactor, QObject* parent)
     : QObject(parent)
     , type(type)
     , baseUnit(baseUnit)
@@ -453,7 +453,7 @@ void IUnit::meter2elevation(qreal meter, QString& val, QString& unit) const
 {
     if(meter == NOFLOAT || meter == NOINT)
     {
-        val  = "-";
+        val = "-";
         unit.clear();
     }
     else
@@ -467,7 +467,7 @@ void IUnit::meter2elevation(qreal meter, qreal& val, QString& unit) const
 {
     if(meter == NOFLOAT)
     {
-        val  = NOFLOAT;
+        val = NOFLOAT;
         unit.clear();
     }
     else
@@ -484,7 +484,7 @@ void IUnit::meter2base(qreal meter, QString& val, QString& unit) const
     val.sprintf("%1.0f", meter * baseFactor);
 }
 
-bool IUnit::convert(qreal &value, QString &unit, const QString &targetUnit)
+bool IUnit::convert(qreal& value, QString& unit, const QString& targetUnit)
 {
     unit = unit.toLower(); //since comparison is made in lower
     if(unit == targetUnit)
@@ -565,7 +565,7 @@ bool IUnit::convert(qreal &value, QString &unit, const QString &targetUnit)
     }
 }
 
-void IUnit::slope2string(qreal slope, QString &val, QString &unit)
+void IUnit::slope2string(qreal slope, QString& val, QString& unit)
 {
     if(slope == NOFLOAT)
     {
@@ -602,7 +602,7 @@ qreal IUnit::slopeConvert(IUnit::slope_mode_e fromMode, qreal fromSlope)
     return ret;
 }
 
-void IUnit::slope2unit(qreal slope, qreal &val, QString &unit)
+void IUnit::slope2unit(qreal slope, qreal& val, QString& unit)
 {
     switch(slopeMode)
     {
@@ -618,7 +618,7 @@ void IUnit::slope2unit(qreal slope, qreal &val, QString &unit)
     }
 }
 
-void IUnit::setUnitType(type_e t, QObject * parent)
+void IUnit::setUnitType(type_e t, QObject* parent)
 {
     switch(t)
     {
@@ -673,13 +673,13 @@ void IUnit::seconds2time(quint32 ttime, QString& val, QString& unit) const
 {
     if(ttime == 0)
     {
-        val  = "-";
+        val = "-";
         unit = "";
     }
     else
     {
         QTime time(0, 0, 0);
-        quint32 days  = ttime / 86400;
+        quint32 days = ttime / 86400;
 
         time = time.addSecs(ttime);
 
@@ -696,7 +696,7 @@ void IUnit::seconds2time(quint32 ttime, QString& val, QString& unit) const
     }
 }
 
-bool IUnit::parseTimestamp(const QString &time, QDateTime &datetime)
+bool IUnit::parseTimestamp(const QString& time, QDateTime& datetime)
 {
     int tzoffset;
     datetime = parseTimestamp(time, tzoffset);
@@ -705,7 +705,7 @@ bool IUnit::parseTimestamp(const QString &time, QDateTime &datetime)
 }
 
 
-QDateTime IUnit::parseTimestamp(const QString &timetext, int& tzoffset)
+QDateTime IUnit::parseTimestamp(const QString& timetext, int& tzoffset)
 {
     const QRegExp tzRE("[-+]\\d\\d:\\d\\d$");
     int i;
@@ -745,12 +745,12 @@ QDateTime IUnit::parseTimestamp(const QString &timetext, int& tzoffset)
         // add the literal string to the format so fromString()
         // will succeed
         format += "'";
-        format += timetext.right(6);
+        format += timetext.rightRef(6);
         format += "'";
 
         // calculate the offset
-        int offsetHours(timetext.mid(i + 1, 2).toUInt());
-        int offsetMinutes(timetext.mid(i + 4, 2).toUInt());
+        int offsetHours(timetext.midRef(i + 1, 2).toUInt());
+        int offsetMinutes(timetext.midRef(i + 4, 2).toUInt());
         if (timetext[i] == '-')
         {
             tzoffset = -(60 * offsetHours + offsetMinutes);
@@ -811,7 +811,7 @@ QByteArray IUnit::pos2timezone(const QPointF& pos)
     static QImage imgTimezone = QPixmap(":/pics/timezones.png").toImage();
 
     int x = qRound(2048.0 / 360.0 * (180.0 + pos.x() * RAD_TO_DEG));
-    int y = qRound(1024.0 / 180.0 * (90.0  - pos.y() * RAD_TO_DEG));
+    int y = qRound(1024.0 / 180.0 * (90.0 - pos.y() * RAD_TO_DEG));
 
     QRgb rgb = imgTimezone.pixel(x, y);
 
@@ -847,16 +847,16 @@ void IUnit::degToStr(const qreal& x, const qreal& y, QString& str)
         bool signLat = GPS_Math_Deg_To_DegMin(y, &degN, &minN);
         bool signLon = GPS_Math_Deg_To_DegMin(x, &degE, &minE);
 
-        const QString &lat = signLat ? "S" : "N";
-        const QString &lng = signLon ? "W" : "E";
+        const QString& lat = signLat ? "S" : "N";
+        const QString& lng = signLon ? "W" : "E";
         str.sprintf("%s%02d° %06.3f %s%03d° %06.3f", lat.toUtf8().data(), qAbs(degN), minN, lng.toUtf8().data(), qAbs(degE), minE);
         break;
     }
 
     case eCoordFormat2:
     {
-        const QString &lat = (y < 0) ? "S" : "N";
-        const QString &lng = (x < 0) ? "W" : "E";
+        const QString& lat = (y < 0) ? "S" : "N";
+        const QString& lng = (x < 0) ? "W" : "E";
         str.sprintf("%s%02.6f° %s%03.6f°", lat.toUtf8().data(), qAbs(y), lng.toUtf8().data(), qAbs(x));
         break;
     }
@@ -872,8 +872,8 @@ void IUnit::degToStr(const qreal& x, const qreal& y, QString& str)
         qreal secN = (minN - qFloor(minN)) * 60;
         qreal secE = (minE - qFloor(minE)) * 60;
 
-        const QString &lat = signLat ? "S" : "N";
-        const QString &lng = signLon ? "W" : "E";
+        const QString& lat = signLat ? "S" : "N";
+        const QString& lng = signLon ? "W" : "E";
         str.sprintf("%s%02d° %02d' %02.2f'' %s%03d° %02d' %02.2f''", lat.toUtf8().data(), qAbs(degN), qFloor(minN), secN, lng.toUtf8().data(), qAbs(degE), qFloor(minE), secE);
         break;
     }
@@ -884,55 +884,55 @@ bool IUnit::strToDeg(const QString& str, qreal& lon, qreal& lat)
 {
     if(reCoord2.exactMatch(str))
     {
-        bool signLat    = reCoord2.cap(1) == "S";
-        qreal absLat    = reCoord2.cap(2).toDouble();
+        bool signLat = reCoord2.cap(1) == "S";
+        qreal absLat = reCoord2.cap(2).toDouble();
         lat = signLat ? -absLat : absLat;
 
-        bool signLon    = reCoord2.cap(3) == "W";
-        qreal absLon    = reCoord2.cap(4).toDouble();
+        bool signLon = reCoord2.cap(3) == "W";
+        qreal absLon = reCoord2.cap(4).toDouble();
         lon = signLon ? -absLon : absLon;
     }
     else if(reCoord1.exactMatch(str))
     {
-        bool signLat    = reCoord1.cap(1) == "S";
-        int degLat      = reCoord1.cap(2).toInt();
-        qreal minLat    = reCoord1.cap(3).toDouble();
+        bool signLat = reCoord1.cap(1) == "S";
+        int degLat = reCoord1.cap(2).toInt();
+        qreal minLat = reCoord1.cap(3).toDouble();
 
         GPS_Math_DegMin_To_Deg(signLat, degLat, minLat, lat);
 
-        bool signLon    = reCoord1.cap(4) == "W";
-        int degLon      = reCoord1.cap(5).toInt();
-        qreal minLon    = reCoord1.cap(6).toDouble();
+        bool signLon = reCoord1.cap(4) == "W";
+        int degLon = reCoord1.cap(5).toInt();
+        qreal minLon = reCoord1.cap(6).toDouble();
 
         GPS_Math_DegMin_To_Deg(signLon, degLon, minLon, lon);
     }
     else if(reCoord3.exactMatch(str))
     {
-        lat             = reCoord3.cap(1).toDouble();
-        lon             = reCoord3.cap(2).toDouble();
+        lat = reCoord3.cap(1).toDouble();
+        lon = reCoord3.cap(2).toDouble();
     }
     else if(reCoord4.exactMatch(str))
     {
-        bool signLat    = reCoord4.cap(1) == "S";
-        int degLat      = reCoord4.cap(2).toInt();
-        int minLat      = reCoord4.cap(3).toInt();
-        qreal secLat    = reCoord4.cap(4).toFloat();
+        bool signLat = reCoord4.cap(1) == "S";
+        int degLat = reCoord4.cap(2).toInt();
+        int minLat = reCoord4.cap(3).toInt();
+        qreal secLat = reCoord4.cap(4).toFloat();
 
         GPS_Math_DegMinSec_To_Deg(signLat, degLat, minLat, secLat, lat);
 
-        bool signLon    = reCoord4.cap(5) == "W";
-        int degLon      = reCoord4.cap(6).toInt();
-        int minLon      = reCoord4.cap(7).toInt();
-        qreal secLon    = reCoord4.cap(8).toFloat();
+        bool signLon = reCoord4.cap(5) == "W";
+        int degLon = reCoord4.cap(6).toInt();
+        int minLon = reCoord4.cap(7).toInt();
+        qreal secLon = reCoord4.cap(8).toFloat();
 
         GPS_Math_DegMinSec_To_Deg(signLon, degLon, minLon, secLon, lon);
     }
     else if(reCoord5.exactMatch(str))
     {
-        bool signLon    = reCoord4.cap(4) == "W";
-        bool signLat    = reCoord4.cap(2) == "S";
-        lat             = reCoord5.cap(1).toDouble();
-        lon             = reCoord5.cap(3).toDouble();
+        bool signLon = reCoord4.cap(4) == "W";
+        bool signLat = reCoord4.cap(2) == "S";
+        lat = reCoord5.cap(1).toDouble();
+        lon = reCoord5.cap(3).toDouble();
 
         if(signLon)
         {
@@ -1025,8 +1025,8 @@ QMap<QString, qreal> IUnit::speedToMKSMap = {
 QMap<QString, qreal> IUnit::areaToMKSMap = {
     {"m²", 1.0},
     {"km²", 1000.0 * 1000},
-    {"mi²", 1.0 / (CUnitImperial::milePerMeter*CUnitImperial::milePerMeter)},
-    {"ft²", 1.0 / (CUnitImperial::footPerMeter*CUnitImperial::footPerMeter)},
+    {"mi²", 1.0 / (CUnitImperial::milePerMeter* CUnitImperial::milePerMeter)},
+    {"ft²", 1.0 / (CUnitImperial::footPerMeter* CUnitImperial::footPerMeter)},
     {"м²", 1.0},
     {"км²", 1000.0 * 1000},
 };
