@@ -21,7 +21,6 @@
 #include "helpers/CGdalFile.h"
 
 #include <gdal_priv.h>
-#include <ogr_spatialref.h>
 
 #include <QtWidgets>
 
@@ -45,7 +44,7 @@ void CGdalFile::unload()
 void CGdalFile::load(const QString& filename)
 {
     qDebug() << filename;
-    CCanvas * canvas = CMainWindow::self().getCanvas();
+    CCanvas* canvas = CMainWindow::self().getCanvas();
 
     dataset = (GDALDataset*)GDALOpenShared(filename.toUtf8(), GA_ReadOnly);
 
@@ -55,25 +54,9 @@ void CGdalFile::load(const QString& filename)
         return;
     }
 
-    char str[1025] = {0};
-    if(dataset->GetProjectionRef())
-    {
-        strncpy(str, dataset->GetProjectionRef(), sizeof(str) - 1);
-    }
+    proj.init(dataset->GetProjectionRef(), "EPSG:4326");
 
-    {
-        OGRSpatialReference oSRS;
-        const char *wkt = str;
-        oSRS.importFromWkt(&wkt);
-
-        char *proj4 = nullptr;
-        oSRS.exportToProj4(&proj4);
-        proj4str = proj4;
-        pjsrc = pj_init_plus(proj4);
-        free(proj4);
-    }
-
-    GDALRasterBand *pBand = dataset->GetRasterBand(1);
+    GDALRasterBand* pBand = dataset->GetRasterBand(1);
 
     if(nullptr == pBand)
     {
@@ -89,16 +72,16 @@ void CGdalFile::load(const QString& filename)
     rasterBandCount = dataset->GetRasterCount();
     if(rasterBandCount == 1)
     {
-        if(pBand->GetColorInterpretation() ==  GCI_PaletteIndex )
+        if(pBand->GetColorInterpretation() == GCI_PaletteIndex )
         {
-            GDALColorTable * pct = pBand->GetColorTable();
+            GDALColorTable* pct = pBand->GetColorTable();
             for(int i = 0; i < pct->GetColorEntryCount(); ++i)
             {
                 const GDALColorEntry& e = *pct->GetColorEntry(i);
                 colortable << qRgba(e.c1, e.c2, e.c3, e.c4);
             }
         }
-        else if(pBand->GetColorInterpretation() ==  GCI_GrayIndex )
+        else if(pBand->GetColorInterpretation() == GCI_GrayIndex )
         {
             for(int i = 0; i < 256; ++i)
             {
@@ -142,10 +125,10 @@ void CGdalFile::load(const QString& filename)
         dataset->GetGeoTransform( adfGeoTransform );
     }
 
-    xscale  = adfGeoTransform[1];
-    yscale  = adfGeoTransform[5];
-    xrot    = adfGeoTransform[4];
-    yrot    = adfGeoTransform[2];
+    xscale = adfGeoTransform[1];
+    yscale = adfGeoTransform[5];
+    xrot = adfGeoTransform[4];
+    yrot = adfGeoTransform[2];
 
     // Setup the basic transformation. Depending on the type this
     // can be the transformation into pixel coordinates or into
@@ -190,7 +173,7 @@ void CGdalFile::load(const QString& filename)
 
 QString CGdalFile::getProjection() const
 {
-    return proj4str;
+    return proj.getProjSrc();
 }
 
 QString CGdalFile::getInfo() const
@@ -198,14 +181,14 @@ QString CGdalFile::getInfo() const
     QString str;
     QTextStream out(&str);
 
-    if(proj4str.isEmpty())
+    if(!proj.isValid())
     {
         out << "no projection" << endl;
     }
     else
     {
         out << getProjection() << endl;
-        if(pj_is_latlong(pjsrc))
+        if(proj.isSrcLatLong())
         {
             out << "xscale: " << xscale << "px/rad\tyscale: " << yscale << "px/rad" << endl;
         }
