@@ -20,18 +20,18 @@
 #include "CMainWindow.h"
 #include "items/CItemFile.h"
 
-CItemFile::CItemFile(const QString &filename, QListWidget *parent)
+CItemFile::CItemFile(const QString& filename, QListWidget* parent)
     : IItem(filename)
     , QListWidgetItem(parent)
 {
     setText(QFileInfo(filename).completeBaseName());
     drawContext = new CDrawContextPixel(CMainWindow::self().getCanvas(), this);
-    reload();
+    CItemFile::reload();
 }
 
 
 void CItemFile::reload()
 {
     IItem::reload();
-    setToolTip(filename + "\n"  + drawContext->getInfo());
+    setToolTip(filename + "\n" + drawContext->getInfo());
 }
