@@ -27,7 +27,7 @@
 class CAppSetupMac : public IAppSetup
 {
 public:
-    CAppSetupMac(QObject * parent)
+    CAppSetupMac(QObject* parent)
         : IAppSetup(parent)
     {
     }
@@ -38,13 +38,20 @@ public:
     QString defaultCachePath() override;
     QString userDataPath(QString subdir = 0) override;
     QString logDir() override;
-    QString findExecutable(const QString &name) override { return QStandardPaths::findExecutable(name); }
+    QString findExecutable(const QString& name) override { return QStandardPaths::findExecutable(name); }
     QString helpFile() override;
 
 private:
     QDir getApplicationDir(QString subdir);
     void migrateDirContent(QString dest);
     void extendPath();
+
+    static const QString relTranslationDir;
+    static const QString relGdalDir;
+    static const QString relProjDir;
+    static const QString relHelpDir;
+    static const QString relBinDir;
+    static const QString relLogDir;
 };
 
 #endif // CAPPSETUPMAC_H
